<?php

namespace Teknisa\FIN\Modules\ContaPagar\Factory;

use Doctrine\ORM\EntityManager;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Model\Financeiro\Entities\Adiantapagar;
use Teknisa\Model\Financeiro\Entities\Devolucaopag;
use Teknisa\Model\Fiscal\Entities\Notafiscal;
use Teknisa\Model\Financeiro\Entities\Ajbolpag;
use Teknisa\Model\Financeiro\Entities\Boletpagar;
use Teknisa\Model\Financeiro\Entities\Contapagar;

/**
 * Class AjusteTituloFactory
 * @package Teknisa\FIN\Modules\ContaPagar\Factory
 */
class AjusteTituloFactory {

    protected $entityManager;

    /**
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    /**
     * Busca Ajuste Boleto Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @param $cdajuctpag
     * @return Ajbolpag
     */
    public function buscaAjbolpag($nrorg, $cdfilial, $nrlanbolpag, $cdajuctpag){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdfilial']    = $cdfilial;
        $params['nrlanbolpag'] = $nrlanbolpag;
        $params['cdajuctpag']  = $cdajuctpag;

        /** @var Ajbolpag $ajbolpag */
        $ajbolpag = $this->entityManager->getRepository(Ajbolpag::class)->findOneBy($params);

        return $ajbolpag;
    }

    /**
     * Busca Boleto Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @return Boletpagar
     */
    public function buscaBoletpagar($nrorg, $cdfilial, $nrlanbolpag){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdfilial']    = $cdfilial;
        $params['nrlanbolpag'] = $nrlanbolpag;

        /** @var Boletpagar $boletpagar */
        $boletpagar = $this->entityManager->getRepository(Boletpagar::class)->findOneBy($params);

        return $boletpagar;
    }

    /**
     * Busca Conta Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @return Contapagar
     */
    public function buscaContapagar($nrorg, $cdfilial, $nrlanbolpag){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdfilibpag']  = $cdfilial;
        $params['nrlanbolpag'] = $nrlanbolpag;

        /** @var Contapagar $contapagar */
        $contapagar = $this->entityManager->getRepository(Contapagar::class)->findOneBy($params);

        return $contapagar;
    }

    /**
     * Busca Conta Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @return Notafiscal
     */
    public function buscaNotafiscal($nrorg, $cdfilial, $nrlanctonf){
        /** @var $params */
        $params = array();
        $params['nrorg']      = $nrorg;
        $params['cdfilial']   = $cdfilial;
        $params['nrlanctonf'] = $nrlanctonf;

        /** @var Notafiscal $notafiscal */
        $notafiscal = $this->entityManager->getRepository(Notafiscal::class)->findOneBy($params);

        return $notafiscal;
    }

    /**
     * Busca Adiantamento Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @param $cdfiliajbolp
     * @param $cdajuctpag
     * @return Adiantapagar
     */
    public function buscaAdiantaPagar($nrorg, $cdfilial, $nrlanbolpag, $cdfiliajbolp, $cdajuctpag){
        /** @var $params */
        $params = array();
        $params['nrorg']        = $nrorg;
        $params['cdfilial']     = $cdfilial;
        $params['nrlanbolpag']  = $nrlanbolpag;
        $params['cdfiliajbolp'] = $cdfiliajbolp;
        $params['cdajuctpag']   = $cdajuctpag;

        /** @var Adiantapagar $adiantapagar */
        $adiantapagar = $this->entityManager->getRepository(Adiantapagar::class)->findOneBy($params);

        return $adiantapagar;
    }

    /**
     * Busca Devolução Pagar
     * @param $nrorg
     * @param $cdfilibolpag
     * @param $nrlanbolpag
     * @param $cdajuctpag
     * @return Devolucaopag
     */
    public function buscaDevolucaopag($nrorg, $cdfilibolpag, $nrlanbolpag, $cdajuctpag){
        /** @var $params */
        $params = array();
        $params['nrorg']        = $nrorg;
        $params['cdfilibolpag'] = $cdfilibolpag;
        $params['nrlanbolpag']  = $nrlanbolpag;
        $params['cdajuctpag']   = $cdajuctpag;

        /** @var Devolucaopag $devolucaopag */
        $devolucaopag = $this->entityManager->getRepository(Devolucaopag::class)->findOneBy($params);

        return $devolucaopag;
    }

    /**
     * Insere Ajuste Boleto Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @param $cdajuctpag
     * @param $vrajbolpag
     * @return Ajbolpag
     */
    public function inserirAjbolpag(
        $nrorg, $cdfilial, $nrlanbolpag, $cdajuctpag, $vrajbolpag, $idorigajbpag = '1'
    ){

        /** @var Ajbolpag $ajbolpag */
        $ajbolpag = new Ajbolpag();
        $ajbolpag->setNrorg($nrorg);
        $ajbolpag->setCdfilial($cdfilial);
        $ajbolpag->setNrlanbolpag($nrlanbolpag);
        $ajbolpag->setCdajuctpag($cdajuctpag);
        $ajbolpag->setVrajbolpag($vrajbolpag);
        $ajbolpag->setIdorigajbpag($idorigajbpag);
        $ajbolpag->setDtinclusao(DateUtil::getDataAtual());

        return $ajbolpag;
    }

    /**
     * Atualiza Ajuste Boleto Pagar
     * @param Ajbolpag $ajbolpag
     * @param $vrajbolpag
     * @return mixed
     */
    public function atualizaAjbolpag(
        Ajbolpag $ajbolpag, $vrajbolpag
    ){
        $ajbolpag->setVrajbolpag($vrajbolpag);

        return $ajbolpag;
    }

    /**
     * Atualiza Boleto Pagar
     * @param Boletpagar $boletpagar
     * @param $vrfinalbpag
     * @return Boletpagar
     */
    public function atualizaBoletpagar(
        Boletpagar $boletpagar, $vrfinalbpag
    ){
        $boletpagar->setVrfinalbpag($vrfinalbpag);

        return $boletpagar;
    }

    /**
     * Atualiza Nota Fiscal
     * @param Notafiscal $notafiscal
     * @param $vrdevolnfutl
     * @return Notafiscal
     */
    public static function atualizaNotaFiscalDev(
        Notafiscal $notafiscal, $vrdevolnfutl
    ){
        $notafiscal->setVrdevolnfutl($vrdevolnfutl);

        return $notafiscal;
    }
}