<?php
namespace Teknisa\FIN\Modules\MovimentacaoBancaria\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Model\Financeiro\Entities\Movbancario;
use Teknisa\Model\Financeiro\Entities\Movcredbanc;
use Teknisa\Model\Financeiro\Entities\Movdebbanc;
use Teknisa\Model\Financeiro\Entities\Movfluxo;
use Teknisa\Model\Financeiro\Entities\Devolucaorec;
use Teknisa\Model\Financeiro\Entities\Devolucaopag;
use Teknisa\Model\Financeiro\Entities\Adiantareceb;
use Teknisa\Model\Financeiro\Entities\Adiantapagar;
use Teknisa\Model\Financeiro\Entities\Cheque;
use Teknisa\Model\Fiscal\Entities\Notafiscal;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Bco11100LancamentoContaCorrenteFactory
{
    private $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    public function insereMovFluxo($nrorg, $cdempresa, $cdfilial, $cdclassfina, $dtmovfluxo, $idmovfluxo, $vrmovfluxo, $idoperacao){
        /** @var Movfluxo $movfluxo */
        $movfluxo = new Movfluxo();
        $movfluxo->setNrorg($nrorg);
        $movfluxo->setCdfilial($cdfilial);
        $movfluxo->setCdempresa($cdempresa);
        $movfluxo->setCdclassfina($cdclassfina);
        $movfluxo->setDtmovfluxo($dtmovfluxo);
        $movfluxo->setIdmovfluxo($idmovfluxo);
        $movfluxo->setVrentmfluxo($idoperacao == 'E'?$vrmovfluxo:0);
        $movfluxo->setVrsaimfluxo($idoperacao == 'S'?$vrmovfluxo:0);
        $movfluxo->setDtinclusao(DateUtil::getDataAtual());
        $movfluxo->setDtultatu(DateUtil::getDataAtual());

        return $movfluxo;
    }

    public function insereMovbancario($cdreducont, $nrmovbanc, $dtmovbanc, $debcred, $nrdocmbanc, $descricao,
                                      $vrmovicred, $idstconext, $idstatusctbbanc, $nrorg)
    {
        try {
            $movbancario = new Movbancario();
            $movbancario->setCdreducont($cdreducont);
            $movbancario->setNrmovbanc($nrmovbanc);
            $movbancario->setDtmovbanc($dtmovbanc);
            $movbancario->setDtinclusao(DateUtil::getDataAtual());
            $movbancario->setIdmovbanc($debcred);
            $movbancario->setNrdocmbanc($nrdocmbanc);
            $movbancario->setDshismbanc($descricao);
            $movbancario->setVrmovbanc($vrmovicred);
            $movbancario->setIdorigmbanc($debcred);
            $movbancario->setIdstconext($idstconext);
            $movbancario->setIdstatusctbbanc($idstatusctbbanc);
            $movbancario->setNrorg($nrorg);
            return $movbancario;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function insereMovcredbanc($cdreducont, $nrmovicred, $cdclassfina, $cdempresa, $cdfilial,
                                      $dtmovbanc, $idmovfluxo, $nrmovbanc, $cdtpcredbanc, $dtmovicred,
                                      $descricao, $vrmovicred, $cdectbmcred, $cdfililancre, $nrorg,
                                      $cdcliente, $cdforneced)
    {
        try {
            $movcredbanc = new Movcredbanc();
            $movcredbanc->setCdreducont($cdreducont);
            $movcredbanc->setNrmovicred($nrmovicred);
            $movcredbanc->setCdclassfina($cdclassfina);
            $movcredbanc->setCdempresa($cdempresa);
            $movcredbanc->setCdfilial($cdfilial);
            $movcredbanc->setDtmovfluxo($dtmovbanc);
            $movcredbanc->setDtinclusao(DateUtil::getDataAtual());
            $movcredbanc->setIdmovfluxo($idmovfluxo);
            $movcredbanc->setNrmovbanc($nrmovbanc);
            $movcredbanc->setCdtpcredbanc($cdtpcredbanc);
            $movcredbanc->setDtmovicred($dtmovicred);
            $movcredbanc->setDsmovicred($descricao);
            $movcredbanc->setVrmovicred($vrmovicred);
            $movcredbanc->setCdectbmcred($cdectbmcred);
            $movcredbanc->setCdfililancre($cdfililancre);
            $movcredbanc->setNrorg($nrorg);
            $movcredbanc->setCdcliente($cdcliente);
            $movcredbanc->setCdforneced($cdforneced);
            return $movcredbanc;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public static function insereMovdebbanc($cdreducont, $nrmovidebi, $cdclassfina, $cdempresa, $cdfilial,
                                            $dtmovbanc, $idmovfluxo, $nrmovbanc, $cdtpdebibanc, $dtmovidebi,
                                            $descricao, $vrmovicred, $cdectbmdeb, $cdfililandeb, $nrorg,
                                            $cdcliente, $cdforneced, $idlancomcontpag)
    {
        try {
            $movdebbanc = new Movdebbanc();
            $movdebbanc->setCdreducont($cdreducont);
            $movdebbanc->setNrmovidebi($nrmovidebi);
            $movdebbanc->setCdclassfina($cdclassfina);
            $movdebbanc->setCdempresa($cdempresa);
            $movdebbanc->setCdfilial($cdfilial);
            $movdebbanc->setDtmovfluxo($dtmovbanc);
            $movdebbanc->setIdmovfluxo($idmovfluxo);
            $movdebbanc->setNrmovbanc($nrmovbanc);
            $movdebbanc->setCdtpdebibanc($cdtpdebibanc);
            $movdebbanc->setDtmovidebi($dtmovidebi);
            $movdebbanc->setDsmovidebi($descricao);
            $movdebbanc->setVrmovidebi($vrmovicred);
            $movdebbanc->setCdectbmdeb($cdectbmdeb);
            $movdebbanc->setCdfililandeb($cdfililandeb);
            $movdebbanc->setCdcliente($cdcliente);
            $movdebbanc->setCdforneced($cdforneced);
            $movdebbanc->setIdlancomcontpag($idlancomcontpag);
            $movdebbanc->setNrorg($nrorg);
            $movdebbanc->setDtinclusao(DateUtil::getDataAtual());
            return $movdebbanc;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public static function insereAdiantamentoCliente($nradiantareceb, $cdreducont, $nrmovi, $cdfilial, $nrlanctonf, $nrlanbolrec,
                                              $nrseqvenrec, $nrparcelarec, $vrdesconto, $tipoLancamento, $nrorg)
    {
        try {
            $adiantareceb = new Adiantareceb();
            $adiantareceb->setNradiantareceb($nradiantareceb);
            $adiantareceb->setCdreducont($cdreducont);
            ($tipoLancamento == 'C')? $adiantareceb->setNrmovicred($nrmovi) : $adiantareceb->setNrmovidebi($nrmovi);
            $adiantareceb->setCdfilial($cdfilial);
            $adiantareceb->setNrlanctonf($nrlanctonf);
            $adiantareceb->setNrlanbolrec($nrlanbolrec);
            $adiantareceb->setNrseqvenrec($nrseqvenrec);
            $adiantareceb->setNrparcelarec($nrparcelarec);
            $adiantareceb->setVradiantarec($vrdesconto);
            $adiantareceb->setDtadiantarec(DateUtil::getDataAtual());
            $adiantareceb->setNrorg($nrorg);
            $adiantareceb->setDtinclusao(DateUtil::getDataAtual());
            return $adiantareceb;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public static function insereAdiantamentoFornecedor($nradiantapagar, $cdreducont, $nrmovi, $cdfilial, $nrlanctonf, $nrlanbolpag,
                                                        $nrseqvenpag, $nrparcelapag, $vrdesconto, $tipoLancamento, $nrorg)
    {
        try {
            $adiantapagar = new Adiantapagar();
            $adiantapagar->setNradiantapagar($nradiantapagar);
            $adiantapagar->setCdreducont($cdreducont);
            ($tipoLancamento == 'C')? $adiantapagar->setNrmovicred($nrmovi) : $adiantapagar->setNrmovidebi($nrmovi);
            $adiantapagar->setCdfilial($cdfilial);
            $adiantapagar->setNrlanctonf($nrlanctonf);
            $adiantapagar->setNrlanbolpag($nrlanbolpag);
            $adiantapagar->setNrseqvenpag($nrseqvenpag);
            $adiantapagar->setNrparcelapag($nrparcelapag);
            $adiantapagar->setVradiantapag($vrdesconto);
            $adiantapagar->setDtadiantapag(DateUtil::getDataAtual());
            $adiantapagar->setNrorg($nrorg);
            $adiantapagar->setDtinclusao(DateUtil::getDataAtual());
            return $adiantapagar;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public static function insereDevolucaoCliente($nrdevolucaorec, $cdreducont, $nrmovi, $filidevo, $nrnfdevo, $vrdesconto, $tipoLancamento, $nrorg)
    {
        try {
            $devolucaorec = new Devolucaorec();
            $devolucaorec->setNrdevolucaorec($nrdevolucaorec);
            $devolucaorec->setCdreducont($cdreducont);
            ($tipoLancamento == 'C')? $devolucaorec->setNrmovicred($nrmovi) : $devolucaorec->setNrmovidebi($nrmovi);
            $devolucaorec->setCdfilial($filidevo);
            $devolucaorec->setNrlanctonf($nrnfdevo);
            $devolucaorec->setVrdevolucaorec($vrdesconto);
            $devolucaorec->setNrorg($nrorg);
            $devolucaorec->setDtdevolucaorec(DateUtil::getDataAtual());
            $devolucaorec->setDtinclusao(DateUtil::getDataAtual());
            return $devolucaorec;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public static function insereDevolucaoFornecedor($nrdevolucaopag, $cdreducont, $nrmovi, $filidevo, $nrnfdevo, $vrdesconto, $tipoLancamento, $nrorg)
    {
        try {
            $devolucaopag = new Devolucaopag();
            $devolucaopag->setNrdevolucaopag($nrdevolucaopag);
            $devolucaopag->setCdreducont($cdreducont);
            ($tipoLancamento == 'C')? $devolucaopag->setNrmovicred($nrmovi) : $devolucaopag->setNrmovidebi($nrmovi);
            $devolucaopag->setCdfilial($filidevo);
            $devolucaopag->setNrlanctonf($nrnfdevo);
            $devolucaopag->setVrdevolucaopag($vrdesconto);
            $devolucaopag->setNrorg($nrorg);
            $devolucaopag->setDtdevolucaopag(DateUtil::getDataAtual());
            $devolucaopag->setDtinclusao(DateUtil::getDataAtual());
            return $devolucaopag;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getMovbancario($nrorg, $nrmovbanc, $cdreducont)
    {
        try {
            $params = array();
            $params['nrorg'] = $nrorg;
            $params['nrmovbanc'] = $nrmovbanc;
            $params['cdreducont'] = $cdreducont;
            $movbancario = $this->entityManager->getRepository(Movbancario::class)->findOneBy($params);
            return $movbancario;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function updateMovbancario(Movbancario $movbancario, $nrdocmbanc, $dshismbanc)
    {
        try {
            $movbancario->setNrdocmbanc($nrdocmbanc);
            $movbancario->setDshismbanc($dshismbanc);
            return $movbancario;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function updateMovcredbanc($nrorg, $nrmovicred, $dsmovicred, $cdreducont)
    {
        try {
            $params = array();
            $params['nrorg'] = $nrorg;
            $params['nrmovicred'] = $nrmovicred;
            $params['cdreducont'] = $cdreducont;
            $movcredbanc = $this->entityManager->getRepository(Movcredbanc::class)->findOneBy($params);
            $movcredbanc->setDsmovicred($dsmovicred);
            return $movcredbanc;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function updateMovdebbanc($nrorg, $nrmovidebi, $dsmovidebi, $cdreducont)
    {
        try {
            $params = array();
            $params['nrorg'] = $nrorg;
            $params['nrmovidebi'] = $nrmovidebi;
            $params['cdreducont'] = $cdreducont;
            $movdebbanc = $this->entityManager->getRepository(Movdebbanc::class)->findOneBy($params);
            $movdebbanc->setDsmovidebi($dsmovidebi);
            return $movdebbanc;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function updateNotaFiscal($nrorg, $cdfilial, $nrlanctonf, $vrdevolnfutl)
    {
        try {
            $params = array();
            $params['nrorg'] = $nrorg;
            $params['cdfilial'] = $cdfilial;
            $params['nrlanctonf'] = $nrlanctonf;
            $notafiscal = $this->entityManager->getRepository(NotaFiscal::class)->findOneBy($params);
            $vrdevolnfutl = ($notafiscal->getVrdevolnfutl())? $notafiscal->getVrdevolnfutl() + $vrdevolnfutl: $vrdevolnfutl;
            $notafiscal->setVrdevolnfutl($vrdevolnfutl);
            $notafiscal->setNrnotadevol($nrlanctonf);
            $notafiscal->setDtultatu(DateUtil::getDataAtual());
            $notafiscal->setNrorgultatu($nrorg);
            return $notafiscal;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function procedureGravaImpostoBaixa($cdreducont, $nrmovidebi, $idoperacao){
        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'GRAVA_BAIXA_IMPOSTO');
        $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRBAIXA', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDREDUCONT', Param::PARAM_INPUT, $cdreducont, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRMOVIDEBI', Param::PARAM_INPUT, $nrmovidebi, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDOPERACAO', Param::PARAM_INPUT, $idoperacao, Param::PARAM_TYPE_STR));
        $procedure->execute();
    }

    public function getAdiantamentoCliente($nrorg, $cdempresa, $cdcliente)
    {
        $params = array();
        $params['NRORG'] = $nrorg;
        $params['CDEMPRESA'] = $cdempresa;
        $params['CDCLIENTE'] = $cdcliente;
        $sql = "SELECT 0 AS VRTOTDISP,
                       CL.CDCLIENTE,
                       NVL(SUM(AR.VRADIANTAREC), 0) VRTOTADIA,
                       CR.NRLANCTONF,
                       CR.NRSEQVENREC,
                       CR.NRPARCELAREC,
                       CR.CDFILIAL,
                       CR.VRATUAREC VRORIGINAL,
                       0 AS VRDESCONTO,
                       CL.IDTPIJURCLIE,
                       CL.NMRAZSOCCLIE,
                       CL.NRINSJURCLIE,
                       TO_CHAR(CR.DTATUAVENREC, 'DD/MM/YYYY') AS DTATUAVENREC
                  FROM NOTAFISCAL NF
                  JOIN CONTARECEBER CR
                    ON NF.CDEMPRESA       = :CDEMPRESA
                   AND CR.IDSTATREC       = 'B'
                   AND NF.IDNFDISPFIN     = 'S'
                   AND NF.NRORG = :NRORG
                   AND CR.CDFILIAL        = NF.CDFILIAL
                   AND CR.NRLANCTONF      = NF.NRLANCTONF
                   AND CR.NRORG     = NF.NRORG
                  LEFT JOIN ADIANTARECEB AR
                    ON AR.CDFILIAL     = CR.CDFILIAL
                   AND AR.NRLANCTONF  = CR.NRLANCTONF
                   AND AR.NRSEQVENREC = CR.NRSEQVENREC
                   AND AR.NRPARCELAREC = CR.NRPARCELAREC
                   AND AR.NRORG     = CR.NRORG
                  JOIN CLIENTE CL
                    ON CL.CDCLIENTE       = :CDCLIENTE
                   AND CL.CDCLIENTE     = NF.CDCLIENTE
                   AND CL.NRORG     = NF.NRORG
                  JOIN TIPOCTRECEBER TP
                    ON TP.IDTPCTRECEBER   = '2'
                   AND CR.CDTPCTRECEB     = TP.CDTPCTRECEB
                   AND CR.NRORG     = TP.NRORG
                 GROUP BY CR.NRLANCTONF,
                       CR.NRSEQVENREC,
                       CR.NRPARCELAREC,
                       CR.CDFILIAL,
                       CR.VRATUAREC,
                       'N',
                       0 ,
                       CL.IDTPIJURCLIE,
                       CL.NMRAZSOCCLIE,
                       CL.NRINSJURCLIE,
                       CR.DTATUAVENREC,
                       CL.CDCLIENTE
                HAVING NVL(SUM(AR.VRADIANTAREC), 0) <> CR.VRATUAREC";
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getAdiantamentoFornecedor($nrorg, $cdempresa, $cdforneced, $nrinsjurforn)
    {
        $params = array();
        $params['NRORG'] = $nrorg;
        $params['CDEMPRESA'] = $cdempresa;
        $params['CDFORNECED'] = $cdforneced;
        $params['NRINSJURFORN'] = $nrinsjurforn;
        $sql = "SELECT NVL(SUM(AP.VRADIANTAPAG), 0) VRTOTADIA,
                    NVL((CP.VRATUAPAG-SUM(NVL(AP.VRADIANTAPAG,0))),0) AS VRTOTDISP,
                    CP.NRLANCTONF,
                    CP.NRSEQVENPAG,
                    CP.NRPARCELAPAG,
                    CP.CDFILIAL,
                    CP.VRATUAPAG VRORIGINAL,
                    0 VRDESCONTO,
                    FR.IDTPIJURFORN,
                    FR.NMRAZSOCFORN,
                    FR.NRINSJURFORN,
                    CP.DTATUAVENPAG,
                    CP.NRORG,
                    NF.NRNOTAFISC
                    FROM
                    NOTAFISCAL NF,
                    CONTAPAGAR CP,
                    ADIANTAPAGAR AP,
                    TIPOCTPAGAR TP,
                    (SELECT CDFORNECED, IDTPIJURFORN, NMRAZSOCFORN, NRINSJURFORN, NRORG
                    FROM FORNECEDOR
                    WHERE CDFORNECED = :CDFORNECED
                    UNION ALL
                    SELECT CDFORNECED, IDTPIJURFORN, NMRAZSOCFORN, NRINSJURFORN, NRORG
                    FROM FORNECEDOR
                    WHERE CDFORNECED <> :CDFORNECED
                    AND SUBSTR(NRINSJURFORN, 1, 8) = SUBSTR(:NRINSJURFORN, 1, 8)) FR
                    WHERE
                    NF.CDFORNECED = FR.CDFORNECED AND
                    NF.NRORG = FR.NRORG AND
                    NF.CDEMPRESA = :CDEMPRESA AND
                    CP.CDFILIAL = NF.CDFILIAL AND
                    CP.NRLANCTONF = NF.NRLANCTONF AND
                    CP.NRORG = NF.NRORG AND
                    AP.CDFILIAL (+) = CP.CDFILIAL AND
                    AP.NRLANCTONF (+) = CP.NRLANCTONF AND
                    AP.NRSEQVENPAG (+) = CP.NRSEQVENPAG AND
                    AP.NRPARCELAPAG(+) = CP.NRPARCELAPAG AND
                    AP.NRORG(+) = CP.NRORG AND
                    CP.CDTPCTPAGAR = TP.CDTPCTPAGAR AND
                    CP.NRORG = TP.NRORG AND
                    TP.IDTPCTPAGAR = '2' AND
                    NF.IDNFDISPFIN = 'S' AND
                    CP.IDSTATPAG = 'B' AND
                    CP.NRORG = :NRORG
                    GROUP BY
                    CP.NRLANCTONF,
                    CP.NRSEQVENPAG,
                    CP.NRPARCELAPAG,
                    CP.CDFILIAL,
                    CP.VRATUAPAG,
                    'N',
                    0 ,
                    FR.IDTPIJURFORN,
                    FR.NMRAZSOCFORN,
                    FR.NRINSJURFORN,
                    CP.DTATUAVENPAG,
                    CP.NRORG,
                    NF.NRNOTAFISC
                    HAVING
                    NVL(SUM(AP.VRADIANTAPAG),0) <> CP.VRATUAPAG";
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getDevolucaoCliente($nrorg, $cdempresa, $cdcliente)
    {
        $params = array();
        $params['NRORG'] = $nrorg;
        $params['CDEMPRESA'] = $cdempresa;
        $params['CDCLIENTE'] = $cdcliente;
        $sql = "SELECT CL.NMRAZSOCCLIE
                  FROM NOTAFISCAL NFD
                  JOIN ITEMNOTAFISC ITF
                    ON (NFD.IDNFDISPFIN  = 'S')
                   AND (NFD.VRNOTAFISC  <> NVL(NFD.VRDEVOLNFUTL, 0))
                   AND (NFD.IDENTRSAIDOP = 'E')
                   AND (NFD.IDSTATUS    IN ('A', 'E'))
                   AND (NFD.CDFILIAL     = ITF.CDFILIAL)
                   AND (NFD.NRLANCTONF   = ITF.NRLANCTONF)
                   AND (NFD.NRORG        = ITF.NRORG)
                  JOIN NOTAFISCAL NFC
                    ON (NFC.CDCLIENTE    = :CDCLIENTE)
                   AND (NFC.CDEMPRESA    = :CDEMPRESA)
                   AND (NFC.NRORG        = :NRORG)
                   AND (ITF.CDFILIALIT   = NFC.CDFILIAL)
                   AND (ITF.NRLANCTONFIT = NFC.NRLANCTONF)
                   AND (ITF.NRORG        = NFC.NRORG)
                  JOIN CLIENTE CL
                    ON (NFC.CDCLIENTE    = CL.CDCLIENTE)
                   AND (NFC.NRORG        = CL.NRORG)
                  JOIN TIPOOPERAC TP
                    ON (TP.IDOPERDEVONF IN ('S'))
                   AND (NFD.IDENTRSAIDOP = TP.IDENTRSAIDOP)
                   AND (NFD.CDTIPOOPER   = TP.CDTIPOOPER)
                   AND (NFD.NRORG        = TP.NRORG)
                 WHERE NOT EXISTS (SELECT CDFILIAL
                                     FROM CONTAPAGAR CP
                                    WHERE CP.CDFILIAL   = NFD.CDFILIAL
                                      AND CP.NRLANCTONF = NFD.NRLANCTONF
                                      AND CP.NRORG      = NFD.NRORG)
                   AND EXISTS (SELECT CDFILIAL
                                 FROM CONTARECEBER
                                WHERE CDFILIAL   = NFC.CDFILIAL
                                  AND NRLANCTONF = NFC.NRLANCTONF
                                  AND NRORG      = NFC.NRORG)";
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getDevolucaoFornecedor($nrorg, $cdempresa, $cdforneced, $lancamentocc = 'N')
    {
        $params = array();
        $params['NRORG'] = $nrorg;
        $params['CDEMPRESA'] = $cdempresa;
        $params['CDFORNECED'] = $cdforneced;
        
        if($lancamentocc == 'N'){
            $sql = "SELECT DISTINCT
                         NRORG,
                         IDMARCADO,
                         DOCUMENTO,
                         FILIDEVO,
                         NRNFDEVO,
                         DTEMISSAO,
                         VRDISPONIVEL,
                         VRDESCONTO,
                         VRNFDEVOL,
                         NRINSJURFORN,
                         IDTPIJURFORN,
                         NMRAZSOCFORN,
                         (
                             SELECT
                                 MAX(NRNOTAFISC
                                       || '/'
                                       || CDSERIEENTR)
                             FROM
                                 ITEMNOTAFISC ITF,
                                 NOTAFISCAL NFC
                             WHERE
                                 ITF.CDFILIAL = FILIDEVO
                                 AND ITF.NRLANCTONF = NRNFDEVO
                                 AND NFC.CDFILIAL = ITF.CDFILIALIT
                                 AND NFC.NRLANCTONF = ITF.NRLANCTONFIT
                         ) AS DOCUMENTOORI
                     FROM
                         (
                             SELECT
                                 NFC.NRORG,
                                 'N' AS IDMARCADO,
                                 NFD.NRNOTAFISC
                                 || '/'
                                 || NFD.CDSERIE DOCUMENTO,
                                 NFD.CDFILIAL     FILIDEVO,
                                 NFD.NRLANCTONF   NRNFDEVO,
                                 NFC.CDFILIAL     FILICOMPRA,
                                 NFC.NRLANCTONF   NRNFCOMPRA,
                                 NFD.DTEMISSAO,
                                 NFD.VRNOTAFISC - NVL(NFD.VRDEVOLNFUTL,0) VRDISPONIVEL,
                                 0 VRDESCONTO,
                                 NFD.VRNOTAFISC   VRNFDEVOL,
                                 FO.NRINSJURFORN,
                                 FO.IDTPIJURFORN,
                                 FO.NMRAZSOCFORN,
                                 NFC.NRNOTAFISC
                                 || '/'
                                 || NFC.CDSERIE DOCUMENTOORI
                             FROM
                                 NOTAFISCAL NFC,
                                 CONTAPAGAR CP,
                                 ITEMNOTAFISC ITF,
                                 NOTAFISCAL NFD,
                                 (
                                     SELECT
                                         IDENTRSAIDOP,
                                         CDTIPOOPER
                                     FROM
                                         TIPOOPERAC
                                     WHERE
                                         IDOPERDEVONF = 'S'
                                 ) TP,
                                 (
                                     SELECT
                                         CDFORNECED,
                                         NRINSJURFORN,
                                         IDTPIJURFORN,
                                         NMRAZSOCFORN,
                                         NRORG
                                     FROM
                                         FORNECEDOR
                                     WHERE
                                         CDFORNECED =:CDFORNECED
                                 ) FO
                             WHERE
                                 NFC.IDENTRSAIDOP = 'E'
                                 AND NFC.CDEMPRESA =:CDEMPRESA
                                 AND NFC.CDFILIAL = CP.CDFILIAL
                                 AND NFC.NRLANCTONF = CP.NRLANCTONF
                                 AND NFC.CDFORNECED = FO.CDFORNECED (+)
                                 AND NFC.CDFILIAL = ITF.CDFILIALIT
                                 AND NFC.NRLANCTONF = ITF.NRLANCTONFIT
                                 AND NFD.IDSTATUS IN ( 'A', 'E' )
                                 AND NFD.IDNFDISPFIN = 'S'
                                 AND NFD.IDENTRSAIDOP = 'S'
                                 AND NFD.CDFILIAL = ITF.CDFILIAL
                                 AND NFD.NRLANCTONF = ITF.NRLANCTONF
                                 AND NFD.IDENTRSAIDOP = TP.IDENTRSAIDOP
                                 AND NFD.CDTIPOOPER = TP.CDTIPOOPER
                                 AND NFC.NRORG = CP.NRORG
                                 AND NFC.NRORG = ITF.NRORG
                                 AND NFC.NRORG = FO.NRORG
                                 AND NFD.NRORG = ITF.NRORG
                                 AND NOT EXISTS (
                                     SELECT
                                         1
                                     FROM
                                         CONTARECEBER CR
                                     WHERE
                                         CR.CDFILIAL = NFD.CDFILIAL
                                         AND CR.NRLANCTONF = NFD.NRLANCTONF
                                 )
                                 AND EXISTS (
                                     SELECT
                                         1
                                     FROM
                                         CONTAPAGAR CP
                                     WHERE
                                         CP.CDFILIAL = NFC.CDFILIAL
                                         AND CP.NRLANCTONF = NFC.NRLANCTONF
                                 )
                         )
                     WHERE
                         VRDISPONIVEL > 0
                         AND NRORG = :NRORG
                     ORDER BY
                         DOCUMENTO,
                         DTEMISSAO";
        }else{
            $sql = "SELECT DISTINCT
                         NRORG,
                         IDMARCADO,
                         DOCUMENTO,
                         FILIDEVO,
                         NRNFDEVO,
                         DTEMISSAO,
                         VRDISPONIVEL,
                         VRDESCONTO,
                         VRNFDEVOL,
                         NRINSJURFORN,
                         IDTPIJURFORN,
                         NMRAZSOCFORN,
                         (
                             SELECT
                                 MAX(NRNOTAFISC
                                       || '/'
                                       || CDSERIEENTR)
                             FROM
                                 ITEMNOTAFISC ITF,
                                 NOTAFISCAL NFC
                             WHERE
                                 ITF.CDFILIAL = FILIDEVO
                                 AND ITF.NRLANCTONF = NRNFDEVO
                                 AND NFC.CDFILIAL = ITF.CDFILIALIT
                                 AND NFC.NRLANCTONF = ITF.NRLANCTONFIT
                         ) AS DOCUMENTOORI
                     FROM
                         (
                             SELECT
                                 NFC.NRORG,
                                 'N' AS IDMARCADO,
                                 NFD.NRNOTAFISC
                                 || '/'
                                 || NFD.CDSERIE DOCUMENTO,
                                 NFD.CDFILIAL     FILIDEVO,
                                 NFD.NRLANCTONF   NRNFDEVO,
                                 NFC.CDFILIAL     FILICOMPRA,
                                 NFC.NRLANCTONF   NRNFCOMPRA,
                                 NFD.DTEMISSAO,
                                 NFD.VRNOTAFISC - NVL(NFD.VRDEVOLNFUTL,0) VRDISPONIVEL,
                                 0 VRDESCONTO,
                                 NFD.VRNOTAFISC   VRNFDEVOL,
                                 FO.NRINSJURFORN,
                                 FO.IDTPIJURFORN,
                                 FO.NMRAZSOCFORN,
                                 NFC.NRNOTAFISC
                                 || '/'
                                 || NFC.CDSERIE DOCUMENTOORI
                             FROM
                                 NOTAFISCAL NFC,
                                 CONTAPAGAR CP,
                                 ITEMNOTAFISC ITF,
                                 NOTAFISCAL NFD,
                                 (
                                     SELECT
                                         IDENTRSAIDOP,
                                         CDTIPOOPER
                                     FROM
                                         TIPOOPERAC
                                     WHERE
                                         IDOPERDEVONF = 'S'
                                 ) TP,
                                 (
                                     SELECT
                                         CDFORNECED,
                                         NRINSJURFORN,
                                         IDTPIJURFORN,
                                         NMRAZSOCFORN,
                                         NRORG
                                     FROM
                                         FORNECEDOR
                                 ) FO
                             WHERE
                                 NFC.IDENTRSAIDOP = 'E'
                                 AND NFC.CDFILIAL = CP.CDFILIAL
                                 AND NFC.NRLANCTONF = CP.NRLANCTONF
                                 AND NFC.CDFORNECED = FO.CDFORNECED (+)
                                 AND NFC.CDFILIAL = ITF.CDFILIALIT
                                 AND NFC.NRLANCTONF = ITF.NRLANCTONFIT
                                 AND NFD.IDSTATUS IN ( 'A', 'E' )
                                 AND NFD.IDNFDISPFIN = 'S'
                                 AND NFD.IDENTRSAIDOP = 'S'
                                 AND NFD.CDFILIAL = ITF.CDFILIAL
                                 AND NFD.NRLANCTONF = ITF.NRLANCTONF
                                 AND NFD.IDENTRSAIDOP = TP.IDENTRSAIDOP
                                 AND NFD.CDTIPOOPER = TP.CDTIPOOPER
                                 AND NFC.NRORG = CP.NRORG
                                 AND NFC.NRORG = ITF.NRORG
                                 AND NFC.NRORG = FO.NRORG
                                 AND NFD.NRORG = ITF.NRORG
                                 AND NOT EXISTS (
                                     SELECT
                                         1
                                     FROM
                                         CONTARECEBER CR
                                     WHERE
                                         CR.CDFILIAL = NFD.CDFILIAL
                                         AND CR.NRLANCTONF = NFD.NRLANCTONF
                                 )
                                 AND EXISTS (
                                     SELECT
                                         1
                                     FROM
                                         CONTAPAGAR CP
                                     WHERE
                                         CP.CDFILIAL = NFC.CDFILIAL
                                         AND CP.NRLANCTONF = NFC.NRLANCTONF
                                 )
                         )
                     WHERE
                         VRDISPONIVEL > 0
                         AND NRORG = :NRORG
                     ORDER BY
                         DOCUMENTO,
                         DTEMISSAO";
        }
        
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getAdiantareceb($nrorg, $cdreducont, $nrmovbanc, $fieldMovimento){
        $params = array();
        $params['nrorg'] = $nrorg;
        $params[$fieldMovimento] = $nrmovbanc;
        $params['cdreducont'] = $cdreducont;
        $adiantamento = $this->entityManager->getRepository(Adiantareceb::class)->findBy($params);
        return $adiantamento;
    }

    public function getAdiantapagar($nrorg, $cdreducont, $nrmovbanc, $fieldMovimento){
        $params = array();
        $params['nrorg'] = $nrorg;
        $params[$fieldMovimento] = $nrmovbanc;
        $params['cdreducont'] = $cdreducont;
        $adiantamento = $this->entityManager->getRepository(Adiantapagar::class)->findBy($params);
        return $adiantamento;
    }

    public function getDevolucaorec($nrorg, $cdreducont, $nrmovbanc, $fieldMovimento){
        $params = array();
        $params['nrorg'] = $nrorg;
        $params[$fieldMovimento] = $nrmovbanc;
        $params['cdreducont'] = $cdreducont;
        $devolucao = $this->entityManager->getRepository(Devolucaorec::class)->findBy($params);
        return $devolucao;
    }

    public function getDevolucaopag($nrorg, $cdreducont, $nrmovbanc, $fieldMovimento){
        $params = array();
        $params['nrorg'] = $nrorg;
        $params[$fieldMovimento] = $nrmovbanc;
        $params['cdreducont'] = $cdreducont;
        $devolucao = $this->entityManager->getRepository(Devolucaopag::class)->findBy($params);
        return $devolucao;
    }

    public function deleteLancccusto($nrlanccont, $cdempresa, $nrorg)
    {
        try {
            $params = array();
            $params['P_NRORG'] = $nrorg;
            $params['P_NRLANCCONT'] = $nrlanccont;
            $params['P_CDEMPRESA'] = $cdempresa;
            $sql = "DELETE
                      FROM LANCCCUSTO
                     WHERE NRLANCCONT = :P_NRLANCCONT
                       AND CDEMPRESA  = :P_CDEMPRESA
                       AND NRORG      = :P_NRORG";
            $delete = $this->entityManager->getConnection()->prepare($sql);
            $delete->execute($params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function deleteLanccont($nrlanccont, $cdempresa, $nrorg)
    {
        try {
            $params = array();
            $params['P_NRORG'] = $nrorg;
            $params['P_NRLANCCONT'] = $nrlanccont;
            $params['P_CDEMPRESA'] = $cdempresa;
            $sql = "DELETE
                      FROM LANCCONT
                     WHERE NRLANCCONT = :P_NRLANCCONT
                       AND CDEMPRESA  = :P_CDEMPRESA
                       AND NRORG      = :P_NRORG";
            $delete = $this->entityManager->getConnection()->prepare($sql);
            $delete->execute($params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function deleteMovdebbanc($cdreducont, $nrmovbanc, $nrorg)
    {
        try {
            $params = array();
            $params['P_NRORG'] = $nrorg;
            $params['P_CDREDUCONT'] = $cdreducont;
            $params['P_NRMOVBANC'] = $nrmovbanc;
            $sql = "DELETE
                      FROM MOVDEBBANC
                     WHERE CDREDUCONT = :P_CDREDUCONT
                       AND NRMOVBANC  = :P_NRMOVBANC
                       AND NRORG      = :P_NRORG";
            $delete = $this->entityManager->getConnection()->prepare($sql);
            $delete->execute($params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function deleteMovcredbanc($cdreducont, $nrmovbanc, $nrorg)
    {
        try {
            $params = array();
            $params['P_NRORG'] = $nrorg;
            $params['P_CDREDUCONT'] = $cdreducont;
            $params['P_NRMOVBANC'] = $nrmovbanc;
            $sql = "DELETE
                      FROM MOVCREDBANC
                     WHERE CDREDUCONT = :P_CDREDUCONT
                       AND NRMOVBANC  = :P_NRMOVBANC
                       AND NRORG      = :P_NRORG";
            $delete = $this->entityManager->getConnection()->prepare($sql);
            $delete->execute($params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function deleteMovbancario($nrmovbanc, $cdreducont, $nrorg)
    {
        try {
            $params = array();
            $params['P_NRORG'] = $nrorg;
            $params['P_NRMOVBANC'] = $nrmovbanc;
            $params['P_CDREDUCONT'] = $cdreducont;
            $sql = "DELETE
                      FROM MOVBANCARIO
                     WHERE CDREDUCONT = :P_CDREDUCONT
                       AND NRMOVBANC  = :P_NRMOVBANC
                       AND NRORG      = :P_NRORG";
            $delete = $this->entityManager->getConnection()->prepare($sql);
            $delete->execute($params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getLancamentoDebito($nrorg, $nrmovidebi, $cdreducont, $cdempresa)
    {
        $params = array();
        $params['nrorg'] = $nrorg;
        $params['nrmovidebi'] = $nrmovidebi;
        $params['cdreducont'] = $cdreducont;
        $params['cdempresa'] = $cdempresa;
        $movdebbanc = $this->entityManager->getRepository(Movdebbanc::class)->findOneBy($params);
        return $movdebbanc;
    }

    public function setChequeLancamentoDebito(Movdebbanc $movdebbanc, $nrcheque, $nrorg){
        $movdebbanc->setNrcheque($nrcheque);
        $movdebbanc->setDtultatu(DateUtil::getDataAtual());
        $movdebbanc->setNrorgultatu($nrorg);
        return $movdebbanc;
    }

    public function getCheque($nrcheque, $cdreducont, $nrorg){
        $params = array();
        $params['nrorg'] = $nrorg;
        $params['nrcheque'] = $nrcheque;
        $params['cdreducont'] = $cdreducont;
        $cheque = $this->entityManager->getRepository(Cheque::class)->findOneBy($params);
        return $cheque;
    }

    public function updateSituacaoCheque(Cheque $cheque, $idstcheque, $idtpcanccheq, $dtmovbanc, $vrcheque , $dsnomcheq, $cdmoticanc, $nrorg){
        $cheque->setIdstcheque($idstcheque);
        $cheque->setIdtpcanccheq($idtpcanccheq);
        $cheque->setDtemischeq($dtmovbanc);
        $cheque->setDtmovbancheq($dtmovbanc);
        $cheque->setVrcheque($vrcheque);
        $cheque->setDsnomcheq($dsnomcheq);
        $cheque->setCdmoticanc($cdmoticanc);
        $cheque->setDtultatu(DateUtil::getDataAtual());
        $cheque->setNrorgultatu($nrorg);
        return $cheque;
    }
}