CREATE OR REPLACE TRIGGER USR_EXCLUSAO_NF_ENTRADA
AFTER DELETE ON NOTAFISCAL FOR EACH ROW
DECLARE
   V_DTGRV         DATE;
   V_HRGRV         VARCHAR2(04);

   V_NOVOCODIGOE   INTEGER;
   V_NOVOCODIGOS   INTEGER;
   V_NOVOCODMOVS   INTEGER;
   V_FILIALE       VARCHAR2(10);
   V_FILIALS       VARCHAR2(10);
   V_MAIORCODE     INTEGER;
   V_MAIORCODS     INTEGER;
BEGIN
   V_MAIORCODE := 0;
   V_MAIORCODS := 0;

   /* Retorna data e hora de exportao */
   BEGIN
      SELECT TO_DATE(SYSDATE), TO_CHAR(SYSDATE,'HH24MI')
        INTO V_DTGRV, V_HRGRV
        FROM DUAL;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_DTGRV := NULL;
         V_HRGRV := NULL;
   END;

   SELECT MAX(CDGRUPFILI)
     INTO V_FILIALE
     FROM FILGRUPFILI
    WHERE CDFILIAL = :OLD.CDFILIRECE
      AND USR_IDPROTHEUS = 'S';

   SELECT MAX(CDGRUPFILI)
     INTO V_FILIALS
     FROM FILGRUPFILI
    WHERE CDFILIAL = :OLD.CDFILIEMIT
      AND USR_IDPROTHEUS = 'S';

   /*Rotina para inserir notas fiscais de entrada excluidas*/
   IF NOT V_FILIALE IS NULL THEN

      SELECT MAX(WA_IDNFEC)
      INTO V_MAIORCODE
      FROM USR_ZWA
      WHERE CDFILIAL = :OLD.CDFILIAL
        AND NRLANCTONF = :OLD.NRLANCTONF;

      IF V_MAIORCODE <> 0 THEN
         /* Retorna o sequencial para a tabela */
         BEGIN
            SELECT WA_IDNFEC.NEXTVAL
              INTO V_NOVOCODIGOE
              FROM DUAL;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_NOVOCODIGOE := 1;
         END;
 
         FOR C_USR_ZWA IN (
            /*Carrega as notas ficais de entrada excluidas*/
            SELECT CDFILIAL, NRLANCTONF, WA_EMPRESA, WA_FILIAL, WA_DOC, WA_SERIE, WA_CGC, WA_EMISSAO, WA_EST,
                   WA_FRETE, WA_DESPESA, WA_COND, WA_BASEICM, WA_VALICM, WA_BASEIPI, WA_VALIPI, WA_VALMERC, WA_VALBRUT, WA_TIPO,
                   WA_DESCONT, WA_BRICMS, WA_ICMSRET, WA_IRRF, WA_FORMUL, WA_BASIMP4, WA_BASIMP5, WA_BASIMP6, WA_VALIMP4, WA_VALIMP5, WA_VALIMP6,
                   WA_INSS, WA_ISS, WA_TIPO_NF,
                   WA_ICMS, WA_BASEINS, WA_BASEIR,
                   WA_VALPIS, WA_VALCOFI, WA_VALCSLL, WA_VALIRF, WA_BASEPS3,
                   WA_VALPS3, WA_BASECF3, WA_VALCF3, WA_NFELETR, WA_DTDIGIT
              FROM USR_ZWA
             WHERE CDFILIAL = :OLD.CDFILIAL
               AND NRLANCTONF = :OLD.NRLANCTONF
               AND WA_IDNFEC = V_MAIORCODE) LOOP
            /*Insere nota de entrada excluida*/
            INSERT INTO USR_ZWA
               (CDFILIAL, NRLANCTONF, WA_IDNFEC, WA_EMPRESA, WA_FILIAL, WA_DOC, WA_SERIE, WA_CGC, WA_EMISSAO, WA_EST,
                WA_FRETE, WA_DESPESA, WA_COND, WA_BASEICM, WA_VALICM, WA_BASEIPI, WA_VALIPI, WA_VALMERC, WA_VALBRUT, WA_TIPO,
                WA_DESCONT, WA_BRICMS, WA_ICMSRET, WA_IRRF, WA_FORMUL, WA_BASIMP4, WA_BASIMP5, WA_BASIMP6, WA_VALIMP4, WA_VALIMP5, WA_VALIMP6,
                WA_INSS, WA_ISS, WA_TIPO_NF,
                WA_ICMS, WA_BASEINS, WA_BASEIR,
                WA_VALPIS, WA_VALCOFI, WA_VALCSLL, WA_VALIRF, WA_BASEPS3,
                WA_VALPS3, WA_BASECF3, WA_VALCF3, WA_NFELETR, WA_TPEDI, WA_DTGRV, WA_HRGRV, WA_DTDIGIT)
            VALUES
               (C_USR_ZWA.CDFILIAL, C_USR_ZWA.NRLANCTONF, V_NOVOCODIGOE, C_USR_ZWA.WA_EMPRESA, C_USR_ZWA.WA_FILIAL, C_USR_ZWA.WA_DOC, C_USR_ZWA.WA_SERIE, C_USR_ZWA.WA_CGC, C_USR_ZWA.WA_EMISSAO, C_USR_ZWA.WA_EST,
                C_USR_ZWA.WA_FRETE, C_USR_ZWA.WA_DESPESA, C_USR_ZWA.WA_COND, C_USR_ZWA.WA_BASEICM, C_USR_ZWA.WA_VALICM, C_USR_ZWA.WA_BASEIPI, C_USR_ZWA.WA_VALIPI, C_USR_ZWA.WA_VALMERC, C_USR_ZWA.WA_VALBRUT, C_USR_ZWA.WA_TIPO,
                C_USR_ZWA.WA_DESCONT, C_USR_ZWA.WA_BRICMS, C_USR_ZWA.WA_ICMSRET, C_USR_ZWA.WA_IRRF, C_USR_ZWA.WA_FORMUL, C_USR_ZWA.WA_BASIMP4, C_USR_ZWA.WA_BASIMP5, C_USR_ZWA.WA_BASIMP6, C_USR_ZWA.WA_VALIMP4, C_USR_ZWA.WA_VALIMP5, C_USR_ZWA.WA_VALIMP6,
                C_USR_ZWA.WA_INSS, C_USR_ZWA.WA_ISS, C_USR_ZWA.WA_TIPO_NF,
                C_USR_ZWA.WA_ICMS, C_USR_ZWA.WA_BASEINS, C_USR_ZWA.WA_BASEIR,
                C_USR_ZWA.WA_VALPIS, C_USR_ZWA.WA_VALCOFI, C_USR_ZWA.WA_VALCSLL, C_USR_ZWA.WA_VALIRF, C_USR_ZWA.WA_BASEPS3,
                C_USR_ZWA.WA_VALPS3, C_USR_ZWA.WA_BASECF3, C_USR_ZWA.WA_VALCF3, C_USR_ZWA.WA_NFELETR, '2', V_DTGRV, V_HRGRV, :OLD.DTENTRSAID);
         END LOOP;
         FOR C_USR_ZWB IN (
		    /*Carrega os itens da nota de entrada excluida*/ 
            SELECT CDFILIAL, NRLANCTONF, WB_EMPRESA, WB_FILIAL, WB_DOC, WB_SERIE, WB_CGC, WB_EMISSAO,
                   WB_ITEM, WB_COD, WB_QUANT, WB_VUNIT, WB_TOTAL, WB_CC, WB_CF, WB_VALICM,
                   WB_VALIPI, WB_IPI, WB_PICM, WB_BASEICM, WB_BASEIPI, WB_ICMSRET, WB_BRICMS, WB_DESC,
                   WB_ICMSCOM, WB_TIPO, WB_FORMUL, WB_CLASFIS, WB_BASIMP4, WB_BASIMP5, WB_BASIMP6,
                   WB_VALIMP4, WB_VALIMP5, WB_VALIMP6, WB_TIPO_NF, WB_OPER,
                   WB_BASEIRR, WB_ALIQIRR, WB_VALIRR, WB_BASEISS, WB_ALIQISS, WB_VALISS, WB_BASEINS,
                   WB_ALIQINS, WB_VALINS, WB_ALIQCF3, WB_VALCF3, WB_VALPS3, WB_BASECF3, WB_BASEPS3,
                   WB_ALIQPS3, WB_DTDIGIT
              FROM USR_ZWB
             WHERE CDFILIAL = :OLD.CDFILIAL
               AND NRLANCTONF = :OLD.NRLANCTONF
               AND WB_IDNFEI = V_MAIORCODE) LOOP

            /* Insere itens da nota de entrada excluida */
            INSERT INTO USR_ZWB
               (CDFILIAL, NRLANCTONF, WB_IDNFEI, WB_EMPRESA, WB_FILIAL, WB_DOC, WB_SERIE, WB_CGC, WB_EMISSAO,
                WB_ITEM, WB_COD, WB_QUANT, WB_VUNIT, WB_TOTAL, WB_CC, WB_CF, WB_VALICM,
                WB_VALIPI, WB_IPI, WB_PICM, WB_BASEICM, WB_BASEIPI, WB_ICMSRET, WB_BRICMS, WB_DESC,
                WB_ICMSCOM, WB_TIPO, WB_FORMUL, WB_CLASFIS, WB_BASIMP4, WB_BASIMP5, WB_BASIMP6,
                WB_VALIMP4, WB_VALIMP5, WB_VALIMP6, WB_TIPO_NF, WB_OPER,
                WB_BASEIRR, WB_ALIQIRR, WB_VALIRR, WB_BASEISS, WB_ALIQISS, WB_VALISS, WB_BASEINS,
                WB_ALIQINS, WB_VALINS, WB_ALIQCF3, WB_VALCF3, WB_VALPS3, WB_BASECF3, WB_BASEPS3,
                WB_ALIQPS3, WB_TPEDI, WB_DTGRV, WB_HRGRV, WB_DTDIGIT)
            VALUES
               (C_USR_ZWB.CDFILIAL, C_USR_ZWB.NRLANCTONF, V_NOVOCODIGOE, C_USR_ZWB.WB_EMPRESA, C_USR_ZWB.WB_FILIAL, C_USR_ZWB.WB_DOC, C_USR_ZWB.WB_SERIE, C_USR_ZWB.WB_CGC, C_USR_ZWB.WB_EMISSAO,
                C_USR_ZWB.WB_ITEM, C_USR_ZWB.WB_COD, C_USR_ZWB.WB_QUANT, C_USR_ZWB.WB_VUNIT, C_USR_ZWB.WB_TOTAL, C_USR_ZWB.WB_CC, C_USR_ZWB.WB_CF, C_USR_ZWB.WB_VALICM,
                C_USR_ZWB.WB_VALIPI, C_USR_ZWB.WB_IPI, C_USR_ZWB.WB_PICM, C_USR_ZWB.WB_BASEICM, C_USR_ZWB.WB_BASEIPI, C_USR_ZWB.WB_ICMSRET, C_USR_ZWB.WB_BRICMS, C_USR_ZWB.WB_DESC,
                C_USR_ZWB.WB_ICMSCOM, C_USR_ZWB.WB_TIPO, C_USR_ZWB.WB_FORMUL, C_USR_ZWB.WB_CLASFIS, C_USR_ZWB.WB_BASIMP4, C_USR_ZWB.WB_BASIMP5, C_USR_ZWB.WB_BASIMP6,
                C_USR_ZWB.WB_VALIMP4, C_USR_ZWB.WB_VALIMP5, C_USR_ZWB.WB_VALIMP6, C_USR_ZWB.WB_TIPO_NF, C_USR_ZWB.WB_OPER,
                C_USR_ZWB.WB_BASEIRR, C_USR_ZWB.WB_ALIQIRR, C_USR_ZWB.WB_VALIRR, C_USR_ZWB.WB_BASEISS, C_USR_ZWB.WB_ALIQISS, C_USR_ZWB.WB_VALISS, C_USR_ZWB.WB_BASEINS,
                C_USR_ZWB.WB_ALIQINS, C_USR_ZWB.WB_VALINS, C_USR_ZWB.WB_ALIQCF3, C_USR_ZWB.WB_VALCF3, C_USR_ZWB.WB_VALPS3, C_USR_ZWB.WB_BASECF3, C_USR_ZWB.WB_BASEPS3,
                C_USR_ZWB.WB_ALIQPS3, '2', V_DTGRV, V_HRGRV, :OLD.DTENTRSAID);
         END LOOP;

         FOR C_RATEXCL IN (
            SELECT CDFILIAL, NRLANCTONF, WH_ITEMNF, WH_ITEM, WH_EMPRESA, WH_FILIAL, WH_DOC,
                WH_SERIE, WH_CGC, WH_PERC, WH_CC, WH_CUSTO1
              FROM USR_ZWH
             WHERE CDFILIAL = :OLD.CDFILIAL
               AND NRLANCTONF = :OLD.NRLANCTONF
               AND WH_IDREDZ = V_MAIORCODE) LOOP

            INSERT INTO USR_ZWH
               (CDFILIAL, NRLANCTONF, WH_IDREDZ, WH_ITEMNF, WH_ITEM, WH_EMPRESA, WH_FILIAL, WH_DOC,
                WH_SERIE, WH_CGC, WH_PERC, WH_CC, WH_CUSTO1, WH_TPEDI, WH_DTGRV, WH_HRGRV)
            VALUES
               (C_RATEXCL.CDFILIAL, C_RATEXCL.NRLANCTONF, V_NOVOCODIGOE, C_RATEXCL.WH_ITEMNF, C_RATEXCL.WH_ITEM, C_RATEXCL.WH_EMPRESA, C_RATEXCL.WH_FILIAL, C_RATEXCL.WH_DOC,
                C_RATEXCL.WH_SERIE, C_RATEXCL.WH_CGC, C_RATEXCL.WH_PERC, C_RATEXCL.WH_CC, C_RATEXCL.WH_CUSTO1, '2', V_DTGRV, V_HRGRV);
         END LOOP;
      END IF;
   END IF;
   /*Rotina para inserir notas fiscais de saida excluidas*/
   IF NOT V_FILIALS IS NULL THEN

      SELECT MAX(WE_IDNFSC)
      INTO V_MAIORCODS
      FROM USR_ZWE
      WHERE CDFILIAL = :OLD.CDFILIAL
        AND NRLANCTONF = :OLD.NRLANCTONF;

      IF V_MAIORCODS <> 0 THEN
         /* Retorna o sequencial para a tabela */
         BEGIN
            SELECT WE_IDNFSC.NEXTVAL
              INTO V_NOVOCODIGOS
              FROM DUAL;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_NOVOCODIGOS := 1;
         END;

         FOR C_USR_ZWE IN (
		    /*Carrega as notas fiscais de saida excluidas*/
            SELECT CDFILIAL, NRLANCTONF, WE_IDNFSC, WE_EMPRESA, WE_FILIAL, WE_DOC, WE_SERIE, WE_CGC, WE_EMISSAO,
                   WE_COND, WE_FRETE, WE_SEGURO, WE_NFORI, WE_DESCONT, WE_SERIORI, WE_TIPO, WE_BASEISS, WE_VALISS,
                   WE_BASIMP4, WE_BASIMP5, WE_BASIMP6, WE_VALIMP4, WE_VALIMP5, WE_VALIMP6, WE_VALINSS, WE_BASEINS,
                   WE_BASEICM, WE_VALICM, WE_BASEIPI, WE_VALIPI, WE_VALMERC, WE_VALBRUT, WE_BRICMS, WE_ICMSRET, WE_VALIRRF,
                   WE_FORMUL, WE_VALPIS, WE_VALCOFI, WE_VALCSLL, WE_BASEPS3,
                   WE_VALPS3, WE_BASECF3, WE_VALCF3, WE_NFELETR, WE_TPEDI, WE_DTGRV, WE_HRGRV
              FROM USR_ZWE
             WHERE CDFILIAL = :OLD.CDFILIAL
               AND NRLANCTONF = :OLD.NRLANCTONF
               AND WE_IDNFSC = V_MAIORCODS) LOOP
            /*Insere a nota fiscal de saida excluida*/
            INSERT INTO USR_ZWE
               (CDFILIAL, NRLANCTONF, WE_IDNFSC, WE_EMPRESA, WE_FILIAL, WE_DOC, WE_SERIE, WE_CGC, WE_EMISSAO,
                WE_COND, WE_FRETE, WE_SEGURO, WE_NFORI, WE_DESCONT, WE_SERIORI, WE_TIPO, WE_BASEISS, WE_VALISS,
                WE_BASIMP4, WE_BASIMP5, WE_BASIMP6, WE_VALIMP4, WE_VALIMP5, WE_VALIMP6, WE_VALINSS, WE_BASEINS,
                WE_BASEICM, WE_VALICM, WE_BASEIPI, WE_VALIPI, WE_VALMERC, WE_VALBRUT, WE_BRICMS, WE_ICMSRET, WE_VALIRRF,
                WE_FORMUL, WE_VALPIS, WE_VALCOFI, WE_VALCSLL, WE_BASEPS3,
                WE_VALPS3, WE_BASECF3, WE_VALCF3, WE_NFELETR, WE_TPEDI, WE_DTGRV, WE_HRGRV)
            VALUES
               (C_USR_ZWE.CDFILIAL, C_USR_ZWE.NRLANCTONF, V_NOVOCODIGOS, C_USR_ZWE.WE_EMPRESA, C_USR_ZWE.WE_FILIAL, C_USR_ZWE.WE_DOC, C_USR_ZWE.WE_SERIE, C_USR_ZWE.WE_CGC, C_USR_ZWE.WE_EMISSAO,
                C_USR_ZWE.WE_COND, C_USR_ZWE.WE_FRETE, C_USR_ZWE.WE_SEGURO, C_USR_ZWE.WE_NFORI, C_USR_ZWE.WE_DESCONT, C_USR_ZWE.WE_SERIORI, C_USR_ZWE.WE_TIPO, C_USR_ZWE.WE_BASEISS, C_USR_ZWE.WE_VALISS,
                C_USR_ZWE.WE_BASIMP4, C_USR_ZWE.WE_BASIMP5, C_USR_ZWE.WE_BASIMP6, C_USR_ZWE.WE_VALIMP4, C_USR_ZWE.WE_VALIMP5, C_USR_ZWE.WE_VALIMP6, C_USR_ZWE.WE_VALINSS, C_USR_ZWE.WE_BASEINS,
                C_USR_ZWE.WE_BASEICM, C_USR_ZWE.WE_VALICM, C_USR_ZWE.WE_BASEIPI, C_USR_ZWE.WE_VALIPI, C_USR_ZWE.WE_VALMERC, C_USR_ZWE.WE_VALBRUT, C_USR_ZWE.WE_BRICMS, C_USR_ZWE.WE_ICMSRET, C_USR_ZWE.WE_VALIRRF,
                C_USR_ZWE.WE_FORMUL, C_USR_ZWE.WE_VALPIS, C_USR_ZWE.WE_VALCOFI, C_USR_ZWE.WE_VALCSLL, C_USR_ZWE.WE_BASEPS3,
                C_USR_ZWE.WE_VALPS3, C_USR_ZWE.WE_BASECF3, C_USR_ZWE.WE_VALCF3, C_USR_ZWE.WE_NFELETR, '2', V_DTGRV, V_HRGRV);
         END LOOP;
         
         FOR C_USR_ZWF IN (
		    /*Carrega os itens da nota fiscal de saida excluida*/
            SELECT CDFILIAL, NRLANCTONF, WF_EMPRESA, WF_FILIAL, WF_DOC, WF_SERIE, WF_CGC,
                   WF_ITEM, WF_COD, WF_QUANT, WF_PRCVEN, WF_TOTAL, WF_CF, WF_VALICM,
                   WF_DESC, WF_EMISSAO, WF_TIPO, WF_NFORI, WF_SERIORI, WF_QTDEDEV, WF_VALDEV,
                   WF_CLASFIS, WF_BASIMP4, WF_BASIMP5, WF_BASIMP6, WF_VALIMP4, WF_VALIMP5, WF_VALIMP6,
                   WF_ALQIMP4, WF_ALQIMP5, WF_ALQIMP6, WF_FORMUL, WF_VALBRUT,
                   WF_VALIPI, WF_IPI, WF_PICM, WF_BASEICM, WF_BASEIPI, WF_ICMSRET, WF_BRICMS,
                   WF_BASEIRR, WF_BASEISS, WF_ALIQISS, WF_VALISS, WF_BASEINS,
                   WF_ALIQINS, WF_VALINS, WF_ALIQCF3, WF_VALCF3, WF_VALPS3, WF_BASECF3, WF_BASEPS3,
                   WF_ALIQPS3
              FROM USR_ZWF
             WHERE CDFILIAL = :OLD.CDFILIAL
               AND NRLANCTONF = :OLD.NRLANCTONF
               AND WF_IDNFSI = V_MAIORCODS) LOOP

            /* Insere itens da nota fiscal */
            INSERT INTO USR_ZWF
               (CDFILIAL, NRLANCTONF, WF_IDNFSI, WF_EMPRESA,
                WF_FILIAL, WF_DOC, WF_SERIE, WF_CGC,
                WF_ITEM, WF_COD, WF_QUANT, WF_PRCVEN,
                WF_TOTAL, WF_CF, WF_VALICM,
                WF_DESC, WF_EMISSAO, WF_TIPO, WF_NFORI,
                WF_SERIORI, WF_QTDEDEV, WF_VALDEV,
                WF_CLASFIS, WF_BASIMP4, WF_BASIMP5, WF_BASIMP6,
                WF_VALIMP4, WF_VALIMP5, WF_VALIMP6,
                WF_ALQIMP4, WF_ALQIMP5, WF_ALQIMP6,
                WF_FORMUL, WF_VALBRUT,
                WF_VALIPI, WF_IPI, WF_PICM, WF_BASEICM,
                WF_BASEIPI, WF_ICMSRET, WF_BRICMS,
                WF_BASEIRR, WF_BASEISS, WF_ALIQISS,
                WF_VALISS, WF_BASEINS,
                WF_ALIQINS, WF_VALINS, WF_ALIQCF3,
                WF_VALCF3, WF_VALPS3, WF_BASECF3, WF_BASEPS3,
                WF_ALIQPS3, WF_TPEDI, WF_DTGRV, WF_HRGRV)
            VALUES
               (C_USR_ZWF.CDFILIAL, C_USR_ZWF.NRLANCTONF, V_NOVOCODIGOS, C_USR_ZWF.WF_EMPRESA,
                C_USR_ZWF.WF_FILIAL, C_USR_ZWF.WF_DOC, C_USR_ZWF.WF_SERIE, C_USR_ZWF.WF_CGC,
                C_USR_ZWF.WF_ITEM, C_USR_ZWF.WF_COD, C_USR_ZWF.WF_QUANT, C_USR_ZWF.WF_PRCVEN,
                C_USR_ZWF.WF_TOTAL, C_USR_ZWF.WF_CF, C_USR_ZWF.WF_VALICM,
                C_USR_ZWF.WF_DESC, C_USR_ZWF.WF_EMISSAO, C_USR_ZWF.WF_TIPO, C_USR_ZWF.WF_NFORI,
                C_USR_ZWF.WF_SERIORI, C_USR_ZWF.WF_QTDEDEV, C_USR_ZWF.WF_VALDEV,
                C_USR_ZWF.WF_CLASFIS, C_USR_ZWF.WF_BASIMP4, C_USR_ZWF.WF_BASIMP5, C_USR_ZWF.WF_BASIMP6,
                C_USR_ZWF.WF_VALIMP4, C_USR_ZWF.WF_VALIMP5, C_USR_ZWF.WF_VALIMP6,
                C_USR_ZWF.WF_ALQIMP4, C_USR_ZWF.WF_ALQIMP5, C_USR_ZWF.WF_ALQIMP6,
                C_USR_ZWF.WF_FORMUL, C_USR_ZWF.WF_VALBRUT,
                C_USR_ZWF.WF_VALIPI, C_USR_ZWF.WF_IPI, C_USR_ZWF.WF_PICM, C_USR_ZWF.WF_BASEICM,
                C_USR_ZWF.WF_BASEIPI, C_USR_ZWF.WF_ICMSRET, C_USR_ZWF.WF_BRICMS,
                C_USR_ZWF.WF_BASEIRR, C_USR_ZWF.WF_BASEISS, C_USR_ZWF.WF_ALIQISS,
                C_USR_ZWF.WF_VALISS, C_USR_ZWF.WF_BASEINS,
                C_USR_ZWF.WF_ALIQINS, C_USR_ZWF.WF_VALINS, C_USR_ZWF.WF_ALIQCF3,
                C_USR_ZWF.WF_VALCF3, C_USR_ZWF.WF_VALPS3, C_USR_ZWF.WF_BASECF3, C_USR_ZWF.WF_BASEPS3,
                C_USR_ZWF.WF_ALIQPS3, '2', V_DTGRV, V_HRGRV);
         END LOOP;
      END IF;
   END IF;
   /*Rotina para os produtos excluidos do estoque*/
   IF ((:OLD.IDENTRSAIDOP = 'S')         AND
       (:OLD.IDSISTEMA IN ('DFS','FAI')) AND
       (:OLD.CDTIPOOPER = '10'))         THEN

      FOR C_ZWG_IT IN (
         SELECT WG_COD, MAX(WG_IDMVEST) AS WG_IDMVEST
           FROM USR_ZWG
          WHERE CDFILIAL = :OLD.CDFILIAL
            AND NRLANCTONF = :OLD.NRLANCTONF
          GROUP BY WG_COD) LOOP

         FOR C_USR_ZWG IN (
            SELECT CDFILIAL, NRLANCTONF, NRLANCESTQ, WG_EMPRESA, WG_FILIAL, WG_TM, WG_COD, WG_LOCAL, WG_QUANT,
                   WG_EMISSAO, WG_CC, WG_CUSTO, WG_DOC, WG_USUARIO, WG_CONTA, WG_ITEMCTA, WG_CLVL,
                   WG_LOTECTL, WG_NUMLOTE, WG_DTVALID
              FROM USR_ZWG
             WHERE CDFILIAL = :OLD.CDFILIAL
               AND NRLANCTONF = :OLD.NRLANCTONF
               AND WG_IDMVEST = C_ZWG_IT.WG_IDMVEST) LOOP

            /* Retorna o sequencial para a tabela */
            BEGIN
               SELECT WG_IDMVEST.NEXTVAL
                 INTO V_NOVOCODMOVS
                 FROM DUAL;
            EXCEPTION
               WHEN NO_DATA_FOUND THEN
                  V_NOVOCODMOVS := 1;
            END;
            /*Insere os itens da nota fiscal excluida*/
            INSERT INTO USR_ZWG
               (WG_IDMVEST, CDFILIAL, NRLANCTONF, NRLANCESTQ, WG_EMPRESA,
                WG_FILIAL, WG_TM, WG_COD, WG_LOCAL, WG_QUANT,
                WG_EMISSAO, WG_CC, WG_CUSTO, WG_DOC, WG_USUARIO,
                WG_CONTA, WG_ITEMCTA, WG_CLVL, WG_LOTECTL,
                WG_NUMLOTE, WG_DTVALID, WG_TPEDI, WG_DTGRV, WG_HRGRV)
            VALUES
               (V_NOVOCODMOVS, C_USR_ZWG.CDFILIAL, C_USR_ZWG.NRLANCTONF, C_USR_ZWG.NRLANCESTQ, C_USR_ZWG.WG_EMPRESA,
                C_USR_ZWG.WG_FILIAL, C_USR_ZWG.WG_TM, C_USR_ZWG.WG_COD, C_USR_ZWG.WG_LOCAL, C_USR_ZWG.WG_QUANT,
                C_USR_ZWG.WG_EMISSAO, C_USR_ZWG.WG_CC, C_USR_ZWG.WG_CUSTO, C_USR_ZWG.WG_DOC, C_USR_ZWG.WG_USUARIO,
                C_USR_ZWG.WG_CONTA, C_USR_ZWG.WG_ITEMCTA, C_USR_ZWG.WG_CLVL, C_USR_ZWG.WG_LOTECTL,
                C_USR_ZWG.WG_NUMLOTE, C_USR_ZWG.WG_DTVALID, '2', V_DTGRV, V_HRGRV);
         END LOOP;
      END LOOP;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('USR_EXCLUSAO_NF_ENTRADA','5.09.000'); END;
/

