var Bco11100_transferenciaContaCorrente_Controller = function(ScreenService, General, templateManager, ZHPromise, restEngine, contabilizacaoController, Bco11100_movimentacaoContaCorrente_Service, ZhFilterPreferences){
    var self = this;

    self.consultarContabilizacaoTransferencia = function(){
        var widget = templateManager.container.getWidget('transferenciaContaCorrente');
        if (widget.currentRow.NRLANCCONT){
            var contabil = [];
            contabil.push({});
            contabil[0].CDEMPRESA  = widget.currentRow.CDEMPRESA;
            contabil[0].NRLANCCONT = widget.currentRow.NRLCTBTRAN;
            contabilizacaoController.exibeContabilizacao(contabil);
        }
    };
    
    self.consultaFiltroTransferencia = function(widget){
        if(widget.appliedFilter){
            if(widget.appliedFilter.FILTER_ROW.CDEMPRESA){
                self.adicionaTransferencia(widget);
            }else{
                ScreenService.showMessage("Filtre uma empresa para continuar");
            }
        }else{
            ScreenService.showMessage("Filtre uma empresa para continuar");
        }
    };

    self.openFilter = function(transferencia){
        self.iniciaTransferenciaFiltro(transferencia)
        .then(function(filterRow){
            self.buscaPadraoEmpresa(filterRow).then(function(filterRow){
                self.abrirFiltro(transferencia, filterRow);
            });
        });
    };

    self.abrirFiltro = function(transferencia, filterRow){
        ZhFilterPreferences.setOriginalFilter(transferencia.id, filterRow);
        ZhFilterPreferences.openFilterWidget(transferencia, filterRow);
    };

    self.buscaPadraoEmpresa = function(filterRow) {
        var deferred = ZHPromise.defer();
        var itens = templateManager.container.getWidget('itensTransferencia');
        var transferencia = templateManager.container.getWidget('transferenciaContaCorrente');
        var filtroFilial = [{"name": "CDFILIAL", "operator": "=", "value": "FILIAL_LOGADA"}];
        var routeFilial = 'fin#/crud/filial';
        General.callRestEngine(routeFilial, 'FilterData', filtroFilial)
        .then(function(response_filial){
            var filial   = response_filial.dataset.filial[0];
            var cdempresa = filial.CDEMPRESA;
            var routeEmpresa = 'fin#/crud/empresa';
            var filtroEmpresa = [{"name": "CDEMPRESA", "operator": "=", "value": cdempresa}];
            General.callRestEngine(routeEmpresa, 'FilterData', filtroEmpresa).then(function (response_empresa){
                var empresa = response_empresa.dataset.empresa[0];
                filterRow.CDEMPRESA = empresa.CDEMPRESA;
                filterRow.NMEMPRESA = empresa.NMEMPRESA;
                transferencia.getField('ORIGEM').dataSourceFilter[0].value = cdempresa;
                transferencia.getField('DESTINO').dataSourceFilter[0].value = cdempresa;
                itens.getField('CDREDUCONT').dataSourceFilter[0].value = cdempresa;
                deferred.resolve(filterRow);
            });
        })
        .catch(function(){
            deferred.resolve(filterRow);
        });
        return deferred.promise;
    };

    self.preparaFiltroTransferencia = function(transferencia, FILTER_ROW){
        var cdempresa = FILTER_ROW.CDEMPRESA;
        var valorInicial = FILTER_ROW.VRTRANBANC_INI;
        var valorFinal = FILTER_ROW.VRTRANBANC_FIN;
        var data = FILTER_ROW.DTTRANBANC;
        var dataIni = data.start;
        var dataFin = data.end;
        var contaOrigem = FILTER_ROW.CONTAORIGEM;
        var contaDestino = FILTER_ROW.CONTADESTINO;
        var historico = FILTER_ROW.HISTORICO;
        transferencia.dataSourceFilter.forEach(function(filtro){
            switch(filtro.name){
                case 'CDEMPRESA': filtro.value = (cdempresa) ? cdempresa : null;
                    break;
                case 'VRTODOS': filtro.value = ((valorInicial == 0) && (valorFinal == 0)) ? 'T' : null;
                    break;
                case 'THISTORICO': filtro.value = (historico) ? null : 'T';
                    break;
                case 'CONTAORIGEM': filtro.value = (contaOrigem) ? contaOrigem : null;
                    break;
                case 'TCONTAORIGEM': filtro.value = (contaOrigem) ? null : 'T';
                    break;
                case 'CONTADESTINO': filtro.value = (contaDestino) ? contaDestino : null;
                    break;
                case 'TCONTADESTINO': filtro.value = (contaDestino) ? null : 'T';
                    break;
                case 'DATAINI': filtro.value = (dataIni) ? dataIni : null;
                    break;
                case 'DATAFIN': filtro.value = (dataFin) ? dataFin : null;
                    break;
                case 'DTTODOS': filtro.value = (!dataIni || !dataFin) ? 'T' : null;
                    break;
            }
        });
    };


    self.habilitaContaCorrente = function(filtro){
        var transferenciaContaCorrente = templateManager.container.getWidget('transferenciaContaCorrente');
        if (filtro.currentRow.NMEMPRESA) {
            transferenciaContaCorrente.getField('ORIGEM').dataSourceFilter[0].value = filtro.currentRow.CDEMPRESA;
            filtro.getField('ORIGEM').readOnly = false;
            filtro.getField('DESTINO').dataSourceFilter[0].value = filtro.currentRow.CDEMPRESA;
            filtro.getField('DESTINO').readOnly = false;
        }else {
            filtro.getField('ORIGEM').dataSourceFilter[0].value = null;
            filtro.getField('ORIGEM').readOnly = true;
            filtro.currentRow.ORIGEM = null;
            filtro.getField('DESTINO').dataSourceFilter[0].value = null;
            filtro.getField('DESTINO').readOnly = true;
            filtro.currentRow.DESTINO = null;
        }
    };

    self.validaStatusAction = function(){

        var itens = templateManager.container.getWidget('itensTransferencia');
        if (itens.mode == 'edit'){
            self.setGridNaoClicavel();
            itens.getAction('EDIT').isVisible = true;
        }else{
            itens.getAction('EDIT').isVisible = false;
        }
    };

    self.setGridNaoClicavel = function(){
        /*var swipe = document.getElementsByClassName('zh-swipe-inner zh-content ng-scope open');
        var div = document.createElement('div');
        div.setAttribute('class', 'swipe-overlay ng-scope');
        div.setAttribute('data-ng-if', 'swipe.editing || swipe.currentWidget.editing');
        swipe[0].appendChild(div);*/
    };

    self.cancelaGridNaoClicavel = function(){
        /*var swipe = document.getElementsByClassName('zh-swipe-inner zh-content ng-scope open');
        var divFilha = document.getElementsByClassName('swipe-overlay ng-scope');
        swipe[0].removeChild(divFilha[divFilha.length - 1]);*/
    };

    self.setTransferenciaContaCorrente = function(transferencia){
        var deferred = ZHPromise.defer();
        //var widgetMovimentacao = templateManager.container.getWidget('movimentacaoContaCorrente');
        transferencia.dataSourceFilter.forEach(function(filtro){
            switch(filtro.name){
                case 'CDEMPRESA': filtro.value = widgetMovimentacao.appliedFilter.FILTER_ROW.CDEMPRESA;
                    break;
                /*case 'CDREDUCONT': filtro.value = (widgetMovimentacao.currentRow.CDREDUCONT) ? widgetMovimentacao.currentRow.CDREDUCONT : null;
                    break;*/
                default: break;
            }
        });
        transferencia.reload().then(function(){
            deferred.resolve();
        });
        return deferred.promise;
    };

    self.iniciaTransferenciaFiltro = function(transferencia){
        var deferred = ZHPromise.defer();
        var route = 'fin#/crud/geral_bco';
        var rowFilter = {};
        rowFilter.VRTRANBANC_INI = 0;
        rowFilter.VRTRANBANC_FIN = 0;
        rowFilter.DEBCRED = 'T';
        General.callRestEngine(route, 'FilterData', [])
            .then(function(response){
                var dttranbanc = transferencia.dataSourceFilter.filter(function(filtro){
                    return filtro.name == 'DTTRANBANC';
                });
                if (dttranbanc.length == 0){
                    var diasAnt  = response.dataset.geral_bco[0].QTDIAANTTRAN;
                    var diasPos  = response.dataset.geral_bco[0].QTDIAAPOTRAN;
                    var start = moment().subtract(diasAnt, 'days').format('DD/MM/YYYY');
                    var end   = moment().add(diasPos, 'days').format('DD/MM/YYYY');
                    var periodoInicial = {
                        "name": "DTTRANBANC",
                        "value": [start, end],
                        "operator": "BETWEEN",
                        "isCustomFilter": true
                    };
                    transferencia.dataSourceFilter.push(periodoInicial);
                    rowFilter.DTTRANBANC = {start: start, end: end};
                }
                transferencia.dataSourceFilter.forEach(function(filtro){
                    switch(filtro.name){
                        case 'VRTODOS': filtro.value = 'T';
                            break;
                        case 'THISTORICO': filtro.value = 'T';
                            break;
                    }
                });
                deferred.resolve(rowFilter);
            })
            .catch(function(erro){
                deferred.resolve(rowFilter);
            });
        return deferred.promise;
    };

    self.adicionaTransferencia = function(transferencia){
        if(transferencia.appliedFilter){
            if(transferencia.appliedFilter.FILTER_ROW.CDEMPRESA){
                var tabbed_itens = templateManager.container.getWidget('tabbed_itensTransferencia');
                ScreenService.openSwipe(tabbed_itens).then(function(){
                    var itens = templateManager.container.getWidget('itensTransferencia');
                    itens.dataSource.data = [];
                    itens.getAction('ADD').isVisible = true;
                    itens.getAction('SAVE').isVisible = false;
                    itens.getAction('DELETE').isVisible = false;
                    itens.getAction('BACK_LIST').isVisible = false;
                    itens.getAction('CANCEL_LIST').isVisible = true;
                    itens.edit();
                    tabbed_itens.currentRow.__is_new = true;
                    self.habilitaFieldsTransferencia(tabbed_itens);
                    tabbed_itens.getField('DTTRANBANC').setValue('');
                    tabbed_itens.getField('VRTRANBANC').setValue('');
                    tabbed_itens.getField('DSHISTTBANC').setValue('');
                    itens.getField('CDREDUCONT').dataSourceFilter[0].value = transferencia.appliedFilter.FILTER_ROW.CDEMPRESA;
                    transferencia.currentRow.IDPERTRANSCCOR = self.requestGeralBco();
                    //self.validaEstadoTabItem(transferencia);
                });
            }else ScreenService.showMessage("Operação bloqueada. Selecione a Empresa no filtro.");
        }else ScreenService.showMessage("Operação bloqueada. Selecione a Empresa no filtro.");

    };

    self.requestGeralBco = function(){
        var route = 'fin#/crud/geral_bco';
        var requestType = {'requestType':'FilterData', "filter": []};
        restEngine.post(route, requestType).then(function(response) {
            return response.dataset.geral_bco[0].IDPERTRANSCCOR;
        });
    };

    self.validaInclusaoContaTransferencia = function(itens){
        var transferencia = templateManager.container.getWidget('transferenciaContaCorrente');
        self.contaJaInformada(itens).then(function(){
            if (transferencia.currentRow.IDPERTRANSCCOR == 'N') {
                var route = 'fin_movimentacaoBancaria#/validaAcessoOperador';
                var row = itens.currentRow;
                General.callRestEngine(route, 'Row', row).then(
                    function(){},
                    function(erro){
                        ScreenService.showMessage(erro.data.error);
                        itens.currentRow.CDREDUCONT = '';
                        itens.currentRow.CDBANCO = '';
                        itens.currentRow.CDAGENCIA = '';
                        itens.currentRow.CDCONTCORR = '';
                        itens.currentRow.DSCONTCORR = '';
                    }
                );
            }
        });
    };

    self.cancelTransferencia = function(){
        var transferencia = templateManager.container.getWidget("transferenciaContaCorrente");
        var itens = templateManager.container.getWidget("itensTransferencia");
        itens.getAction('ADD').isVisible = false;
        itens.getAction('EDIT').isVisible = false;
        itens.getAction('SAVELIST').isVisible = false;
        itens.getAction('DELETE').isVisible = true;
        itens.getAction('BACK_LIST').isVisible = true;
        itens.getAction('CANCEL_LIST').isVisible = false;
        if (transferencia.currentRow.__is_new){
            var indexOfCurrentRow = transferencia.dataSource.data.indexOf(transferencia.currentRow);
            if(indexOfCurrentRow !== -1) {
                transferencia.dataSource.data.pop();
            }
            transferencia.widgets[0].enabled = true;
            transferencia.list();
            ScreenService.closeSwipe();
        } else { //caso a transferencia estiver em modo de edição, recupera o backup e entra no modo de visualização
            Object.keys(transferencia.backupRow).forEach(function(key) {
                transferencia.currentRow[key] = transferencia.backupRow[key];
            }); //copia dados coluna por coluna para não perder referência do objeto da currentRow
            transferencia.view();
        }
    };

    self.editarItensTransferencia = function(itens){
        General.widgetEdit(itens);
        itens.getAction('SAVE').isVisible = true;
        itens.getAction('SAVELIST').isVisible = false;
        itens.getAction('ADD').isVisible = false;
        self.cancelaGridNaoClicavel();
    };

    self.editTransferenciaContaCorrente = function(){
        var tabbed_itens = templateManager.container.getWidget("tabbed_itensTransferencia");
        var itens = templateManager.container.getWidget("itensTransferencia");
        itens.edit();
        self.habilitaFieldsTransferencia(tabbed_itens);
        itens.getAction('EDITTRANSFERENCIA').isVisible = false;
        itens.getAction('SAVE').isVisible = false;
        itens.getAction('ADD').isVisible = true;
        itens.getAction('EDIT').isVisible = true;
        itens.getAction('CANCEL_LIST').isVisible = true;
        var ignoredKeys = ["__rightActions", "__leftActions", "_children", "_parent", "__groupHeaders", "__index", "__isSelected", "__notSelectable", "$$hashKey"];
        tabbed_itens.backupRow = Util.clone(tabbed_itens.currentRow, ignoredKeys);
        itens.dataSource.dataBackup = Util.clone(itens.dataSource.data);
        tabbed_itens.currentRow.__is_new = false;
        tabbed_itens.currentRow.edit = true;
    };

    self.voltarItens = function(){
        ScreenService.closeSwipe().then(function(){
            templateManager.container.getWidget('transferenciaContaCorrente').activate();
        });
    };

    self.voltarListaItens = function(){
        var tabbed_itens = templateManager.container.getWidget("tabbed_itensTransferencia");
        if (tabbed_itens.currentRow.edit || tabbed_itens.currentRow.__is_new){
            ScreenService.closeSwipe().then(function(){
                templateManager.container.getWidget('itensTransferencia').edit();
                self.cancelaGridNaoClicavel();
            });
        }else{
            ScreenService.closeSwipe();
        }
    };

    self.cancelarItens = function(itens){
        var tabbed_itens = templateManager.container.getWidget("tabbed_itensTransferencia");
        if (tabbed_itens.currentRow.edit){
            if (itens.getAction('ADD').isVisible){
                self.cancelaItensModoList(itens, tabbed_itens);
                Object.keys(tabbed_itens.backupRow).forEach(function(key) {
                    tabbed_itens.currentRow[key] = tabbed_itens.backupRow[key];
                });
                itens.dataSource.data = [];
                itens.dataSource.data = itens.dataSource.dataBackup;
                tabbed_itens.currentRow.edit = false;
            }else{
                if (itens.mode == 'edit' && !itens.currentRow.__is_new){
                    self.cancelaModoEdicao(itens).then(function(){
                        self.validaActionFinalizar(itens);
                        self.setGridNaoClicavel();
                    });
                }else if (itens.mode == 'edit' && itens.currentRow.__is_new){
                    ScreenService.closeSwipe().then(function(){
                        self.cancelaGridNaoClicavel();
                        itens.dataSource.data.pop();
                        self.validaActionFinalizar(itens);
                        itens.edit();
                        itens.getAction('ADD').isVisible = true;
                        itens.getAction('SAVE').isVisible = false;
                    });
                }
            }
        }else if (tabbed_itens.currentRow.__is_new){
            if (itens.getAction('ADD').isVisible){
                self.cancelaItensModoList(itens, tabbed_itens);
                ScreenService.closeSwipe().then(function(){
                    templateManager.container.getWidget('transferenciaContaCorrente').activate();
                    itens.dataSource.data = [];
                });
                tabbed_itens.currentRow.__is_new = false;
            }else{
                if (!itens.currentRow.hasOwnProperty('INSERT')){
                    self.cancelaModoEdicao(itens).then(function(){
                        self.validaActionFinalizar(itens);
                        self.setGridNaoClicavel();
                    });
                }else if (itens.currentRow.hasOwnProperty('INSERT')){
                    ScreenService.closeSwipe().then(function(){
                        self.cancelaGridNaoClicavel();
                        itens.dataSource.data.pop();
                        self.validaActionFinalizar(itens);
                        itens.edit();
                        itens.getAction('ADD').isVisible = true;
                        itens.getAction('SAVE').isVisible = false;
                    });
                }
            }
        }
        delete itens.currentRow.INSERT;
    };

    self.cancelaItensModoList = function(itens, tabbed_itens){
        itens.getAction('SAVELIST').isVisible = false;
        itens.getAction('BACK_LIST').isVisible = true;
        itens.getAction('CANCEL_LIST').isVisible = false;
        itens.getAction('ADD').isVisible = false;
        itens.getAction('EDITTRANSFERENCIA').isVisible = true;
        self.desabilitaFieldsTransferencia(tabbed_itens);
        itens.list();
    };

    self.desabilitaFieldsTransferencia = function(tabbed_itens){
        tabbed_itens.getField('DTTRANBANC').template = 'field/span-field.html';
        tabbed_itens.getField('VRTRANBANC').template = 'field/span-field.html';
        tabbed_itens.getField('DSHISTTBANC').template = 'field/span-field.html';
    };

    self.habilitaFieldsTransferencia = function(tabbed_itens){
        tabbed_itens.getField('DTTRANBANC').template = 'field/calendar.html';
        tabbed_itens.getField('VRTRANBANC').template = 'field/text-edit.html';
        tabbed_itens.getField('DSHISTTBANC').template = 'field/text-edit.html';
    };

    self.validaActionFinalizar = function(itens){
        var novoItem = itens.dataSource.data.filter(function(data){
            return data.__is_new;
        });
        if (novoItem.length > 0){
            itens.getAction('SAVELIST').isVisible = true;
        }else{
            itens.getAction('SAVELIST').isVisible = false;
        }
    };

    self.cancelaModoEdicao = function(itens){
        var deferred = ZHPromise.defer();
        itens.view();
        Object.keys(itens.backupRow).forEach(function(key) {
            itens.currentRow[key] = itens.backupRow[key];
        });
        itens.getAction('ADD').isVisible = true;
        itens.getAction('SAVE').isVisible = false;
        deferred.resolve();
        return deferred.promise;
    };

    self.atualizaValoresSelectMultiple = function(widget){
        var fieldsSearch = [];
        fieldsSearch.push(widget.getField('ORIGEM'));
        fieldsSearch.push(widget.getField('DESTINO'));
        fieldsSearch.forEach(function(field) {
            if (field.filterProperties.copyValueSelectMultiple) {
                var valorConcatenado = field.value();
                field.setValue(field.filterProperties.copyValueSelectMultiple);
                field.filterProperties.copyValueSelectMultiple = valorConcatenado;
            }
        });
    };

    self.setDataSourceInterval = function(){
        var widget = templateManager.container.getWidget('transferenciaContaCorrente');
        widget.dataSourceFilter.forEach(function(filtro){
            if (filtro.name.localeCompare('DATAINI') === 0){
                filtro.value = widget.appliedFilter.FILTER_ROW.DTTRANBANC.start;
            }else if (filtro.name.localeCompare('DATAFIN') === 0){
                filtro.value = widget.appliedFilter.FILTER_ROW.DTTRANBANC.end;
            }
        });
    };

    self.validaHistorico = function(widget){
        var valor = (widget.appliedFilter.FILTER_ROW.DSHISMBANC0)? "" : "T";
        widget.dataSourceFilter.forEach(function(filtro) {
            if (filtro.name.localeCompare('THISTORICO') === 0){
                filtro.value = valor;
            }
        });
    };

    self.salvarTransferenciaContaCorrente = function(widget){
        var itens = templateManager.container.getWidget('itensTransferencia');
        var transferencia = templateManager.container.getWidget('tabbed_itensTransferencia');
        var valorTransferencia = parseFloat(transferencia.currentRow.VRTRANBANC.toString().replace('.', '').replace(',', '.'));
        if (itens.getAction('ADD').isVisible) {
            if (self.validaCondicoesParaTransferencia(itens, transferencia)){
                var filtroSaldo = self.preparaFiltroSaldoCC(itens, transferencia);
                var route = 'fin#/crud/sdoccorr';
                General.callRestEngine(route, 'FilterData', filtroSaldo)
                .then(function(response){
                    var contasConcatenadas = self.preparaMensagem(response.dataset.sdoccorr, transferencia);
                    if (contasConcatenadas){
                        ScreenService.confirmMessage('Saldo atual da(s) conta(s) de débito<br>' + contasConcatenadas + ' não comportam o valor da transferencia. Deseja lançar a transferência?', 'question',
                            function (sim) {
                                self.saveTransferencia(transferencia, itens);
                            },
                            function (nao) {
                            }
                        );
                    }else{
                        self.saveTransferencia(transferencia, itens);
                    }
                })
                .catch(function(erro){
                    ScreenService.showMessage(erro.data.error);
                });
            }
        }else{
            self.salvaLocalmente(itens);
        }
    };

    self.salvaLocalmente = function(itens){
        if (itens.isValid()) {
            if (parseFloat(itens.currentRow.VRMOVITBANC.toString().replace('.', '').replace(',', '.')) != 0.00) {
                ScreenService.goBack().then(function(){
                    if (itens.currentRow.INSERT){
                        //self.cancelaGridNaoClicavel();
                    }
                    itens.edit();
                    delete itens.currentRow.INSERT;
                    itens.getAction('SAVELIST').isVisible = true;
                    itens.getAction('SAVE').isVisible = false;
                    itens.getAction('ADD').isVisible = true;
                });
            }else{
                ScreenService.showMessage('Valor deve ser diferente de zero.');
            }
        }
    };

    self.preparaMensagem = function(saldos, transferencia){
        var vrsaldo = (transferencia.currentRow.__is_new) ? parseFloat(transferencia.currentRow.VRTRANBANC) : parseFloat(transferencia.currentRow.VRTRANBANC) - parseFloat(transferencia.backupRow.VRTRANBANC);
        var contasConcatenadas = '';
        saldos.forEach(function(saldo){
            vrsdoccorr = saldo.VRSDOCCORR;
            if ((vrsdoccorr - vrsaldo) <= 0) {
                vrsdoccorr = (vrsdoccorr == 0) ? "0.00" : vrsdoccorr;
                contasConcatenadas = contasConcatenadas + "Conta: " + saldo.CDREDUCONT + " - Saldo: " + vrsdoccorr + ",<br>";
            }
        });
        return contasConcatenadas;
    };

    self.validaCondicoesParaTransferencia = function(itens, transferencia){
        var soma = 0;
        var vrmovitbanc = 0;
        var vrtranbanc = transferencia.currentRow.VRTRANBANC;
        var valorTransferencia = self.formataValoresDecimais(vrtranbanc);
        itens.dataSource.data.forEach(function(data){
            if (data.IDMOVITBANC == 'D'){
                vrmovitbanc = self.formataValoresDecimais(data.VRMOVITBANC);
                soma = soma + vrmovitbanc;
            }
        });
        var transferenciaValida = true;
        if (!transferencia.isValid() && transferenciaValida) {
            transferenciaValida = false;
        }
        if (valorTransferencia == 0.00 && transferenciaValida) {
            transferenciaValida = false;
            ScreenService.showMessage('Valor da transferência deve ser diferente de zero.');
        }
        if (self.existeDiferencaDebitoCredito(itens) && transferenciaValida) {
            transferenciaValida = false;
            ScreenService.showMessage('Soma dos débitos deve ser igual à soma dos créditos.');
        }
        if (valorTransferencia != soma && transferenciaValida) {
            transferenciaValida = false;
            ScreenService.showMessage('Total dos lançamentos difere do valor total da transferência.');
        }

        return transferenciaValida;
    };

    self.preparaFiltroSaldoCC = function(itens, transferencia){
        var contasDebito = itens.dataSource.data
        .filter(function(f){
            return f.IDMOVITBANC == 'D';
        })
        .map(function(m){
            return m.CDREDUCONT;
        });
        var vrsdoccorr = '';
        var  filtroSaldo = [
            {
                "name": "CDREDUCONT",
                "operator": "IN",
                "value": contasDebito
            },
            {
                "name": "DTSDOCCORR",
                "operator": "=",
                "value": transferencia.currentRow.DTTRANBANC
            }
        ];
        return filtroSaldo;
    };

    self.saveTransferencia = function(transferencia, itens){
        var dataSet = self.montaDataSet(itens, transferencia);
        var route = 'fin_movimentacaoBancaria#/saveTransferenciaSaldo';
        
        localStorage.setItem('lancTransRow',JSON.stringify(dataSet));
        localStorage.setItem('TIPOBAIXA','LANCTRANS');
        
        General.callRestEngine(route, 'DataSet', dataSet).then(function (response) {
                transferencia.currentRow.__is_new = false;
                itens.enabled = true;
                itens.getAction('ADD').isVisible = false;
                itens.getAction('SAVELIST').isVisible = false;
                itens.getAction('DELETE').isVisible = true;
                itens.getAction('BACK_LIST').isVisible = true;
                itens.getAction('CANCEL_LIST').isVisible = false;
                self.desabilitaFieldsTransferencia(transferencia);
                itens.list();
                ScreenService.closeSwipe().then(function(){
                    transferencia.getParent().reload();
                    transferencia.getParent().activate();
                    ScreenService.showMessage('Registro salvo com sucesso.');
                });
            },
            function(erro){
                if (contabilizacaoController.checkErrosContabilizacao(erro)){
                    ScreenService.showMessage(erro.data.error);
                }
            }
        );
    };

    self.setSugestaoValor = function(widget){
        var soma = 0;
        widget.dataSource.data.forEach(function(data){
            soma += (data.VRMOVITBANC == '')? 0 : parseFloat(data.VRMOVITBANC);
        });
        var dif = parseFloat(widget.getParent().currentRow.VRTRANBANC) - soma;
        if (dif >= 0) {
            widget.currentRow.VRMOVITBANC = dif;
        }else{
            widget.currentRow.VRMOVITBANC = 0;
        }
    };

    self.contaJaInformada = function(itens){
        var deferred = ZHPromise.defer();
        var count = 0;
        var difcreddeb = false;
        itens.dataSource.data.forEach(function(item){
            if (item.CDREDUCONT == itens.currentRow.CDREDUCONT){
                count++;
            }
        });
        if (count > 1) {
            ScreenService.showMessage('Conta já informada.').then(function(){
                itens.currentRow.CDREDUCONT = '';
                itens.currentRow.CDBANCO = '';
                itens.currentRow.CDAGENCIA = '';
                itens.currentRow.CDCONTCORR = '';
                itens.currentRow.DSCONTCORR = '';
            });
        }else{
            deferred.resolve();
        }
        return deferred.promise;
    };

    self.existeDiferencaDebitoCredito = function(itens){
        var somaCredito = 0;
        var somaDebito = 0;
        var credito = 0;
        var debito = 0;
        var vrmovitbanc = 0;
        itens.dataSource.data.forEach(function(data){
            vrmovitbanc = self.formataValoresDecimais(data.VRMOVITBANC);
            if (data.IDMOVITBANC == 'C'){
                credito = self.formataValoresDecimais(somaCredito);
                somaCredito = credito + vrmovitbanc;
            }
            if (data.IDMOVITBANC == 'D'){
                debito = self.formataValoresDecimais(somaDebito);
                somaDebito = debito + vrmovitbanc;
            }
        });
        return (somaCredito != somaDebito)? true : false;
    };

    self.formataValoresDecimais = function(valor){
        var valorFormatado = 0;
        valorFormatado = (valor.toString().search(',') != '-1') ?
            ((parseFloat(valor.toString().split(',')[0]) > 0) ? parseFloat(valor.toString().replace('.', '').replace(',', '.')) : parseFloat(valor.toString().replace(',', '.'))) :
            parseFloat(valor);
        return valorFormatado;
    };

    self.deleteTransferenciaContaCorrente = function(){
        var transferencia  = templateManager.container.getWidget('transferenciaContaCorrente');
        var itens = templateManager.container.getWidget('itensTransferencia');
        var route = 'fin_movimentacaoBancaria#/deleteTransferenciaContaCorrente';
        var dataSet = self.geraDataDeleteTransferencia(transferencia, itens);
        //var idpertransccor = self.requestGeralBco();
        ScreenService.confirmMessage(ScreenService.i18n('Delete Register?'), 'question',
            function (success) {
                General.callRestEngine(route, 'DataSet', dataSet).then(function (mensagem) {
                    transferencia.reload();
                    ScreenService.closeSwipe().then(function () {
                        transferencia.activate();
                        ScreenService.showMessage(mensagem.messages[0].message);
                    });
                },
                function(erro){
                    ScreenService.showMessage(erro.data.error);
                });
            }
        );
    };

    self.geraDataDeleteTransferencia = function(transferencia, itens){
        var dataSet = [];
        dataSet[0] = {};
        dataSet[0].CDEMPRESA = transferencia.currentRow.CDEMPRESA;
        dataSet[0].VRMOVITBANC = transferencia.currentRow.VRTRANBANC;
        dataSet[0].NRORG = transferencia.currentRow.NRORG;
        dataSet[0].NRTRANBANC = transferencia.currentRow.NRTRANBANC;
        dataSet[0].NRLCTBTRAN = transferencia.currentRow.NRLCTBTRAN;
        dataSet[0].CDFILIAL = transferencia.currentRow.CDFILIAL;
        dataSet[0].CDCLASSFINA = transferencia.currentRow.CDCLASSFINA;
        var itensTransferencia = itens.dataSource.data;
        for(var i = 0; i < itensTransferencia.length; i++){
            dataSet[i + 1]={};
            dataSet[i + 1].CDREDUCONT = itensTransferencia[i].CDREDUCONT;
            dataSet[i + 1].CDEMPRESA = transferencia.currentRow.CDEMPRESA;
            dataSet[i + 1].NRMOVBANC = itensTransferencia[i].NRMOVBANC;
            dataSet[i + 1].VRMOVITBANC = itensTransferencia[i].VRMOVITBANC;
            dataSet[i + 1].NRORG = itensTransferencia[i].NRORG;
            dataSet[i + 1].NRTRANBANC = itensTransferencia[i].NRTRANBANC;
            dataSet[i + 1].IDMOVBANC = itensTransferencia[i].IDMOVITBANC;
        }
        dataSet.forEach(function(data){
            data.DTSDOCCORR = transferencia.currentRow.DTTRANBANC.substr(0, 10);
        });
        return dataSet;
    };

    self.adicionaValorAnteriorDataSet = function(widget){
        widget.dataSource.data.forEach(function(data){
            if (widget.currentRow.CDREDUCONT == data.CDREDUCONT){
                data.VALORANTERIOR = widget.backupRow.VRTRANBANC;
            }
        });
    };

    /**
     * Prepara Row antes de envia-la ao backend.
     * @param itens
     * @param transferencia
     * @returns {Array}
     */
    self.montaDataSet = function(itens, transferencia){
        var historico = transferencia.currentRow.DSHISTTBANC;
        var empresa = transferencia.getParent().appliedFilter.FILTER_ROW.CDEMPRESA;
        var data = transferencia.currentRow.DTTRANBANC;
        var reduzido = transferencia.getParent().appliedFilter.FILTER_ROW.CDREDUCONT;
        var nrtranbanc = transferencia.getParent().currentRow.NRTRANBANC;
        var dataSet = [];
        dataSet[0]={};
        dataSet[0].__is_new = transferencia.currentRow.__is_new;
        dataSet[0].changed = transferencia.currentRow.hasOwnProperty('changed');
        dataSet[0].CDREDUCONT=reduzido;
        dataSet[0].VRMOVITBANC=self.formataValoresDecimais(transferencia.currentRow.VRTRANBANC);
        if (!transferencia.currentRow.__is_new) {
            dataSet[0].DIFERENCASALDO = transferencia.backupRow.VRTRANBANC - transferencia.currentRow.VRTRANBANC;
        }
        dataSet[0].DSHISTTBANC = historico;
        dataSet[0].CDEMPRESA = empresa;
        dataSet[0].DTTRANBANC = data;
        dataSet[0].NRTRANBANC = nrtranbanc;
        dataSet[0].NRMOVBANC = transferencia.currentRow.NRMOVBANC;
        var creditos = itens.dataSource.data;
        for(var i = 0; i < creditos.length; i++){
            dataSet[i + 1]={};
            dataSet[i + 1].__is_new = creditos[i].__is_new;
            dataSet[i + 1].changed = creditos[i].hasOwnProperty('changed');
            dataSet[i + 1].CDREDUCONT=creditos[i].CDREDUCONT;
            dataSet[i + 1].VRMOVITBANC=self.formataValoresDecimais(creditos[i].VRMOVITBANC);
            if (!transferencia.currentRow.__is_new) {
                dataSet[i + 1].DIFERENCASALDO = creditos[i].VRMOVITBANC - creditos[i].SALDOANTERIOR;
            }
            dataSet[i + 1].IDMOVBANC=creditos[i].IDMOVITBANC;
            dataSet[i + 1].DSHISTTBANC = historico;
            dataSet[i + 1].CDEMPRESA = empresa;
            dataSet[i + 1].DTTRANBANC = data;
            dataSet[i + 1].NRTRANBANC = nrtranbanc;
            dataSet[i + 1].NRMOVBANC = creditos[i].NRMOVBANC;
        }
        return dataSet;
    };

    self.openItensTransferencia = function(){
        var tabbed_itens = templateManager.container.getWidget('tabbed_itensTransferencia');
        self.setDadosTransferencia().then(function(){
            ScreenService.openSwipe(tabbed_itens);
        });
    };

    self.setDadosTransferencia = function(){
        var deferred = ZHPromise.defer();
        var transferencia = templateManager.container.getWidget('transferenciaContaCorrente');
        var tabbed_itens = templateManager.container.getWidget('tabbed_itensTransferencia');
        var itens = templateManager.container.getWidget('itensTransferencia');
        itens.dataSourceFilter.forEach(function(filtro){
            if (filtro.name == 'NRTRANBANC'){
                filtro.value = transferencia.currentRow.NRTRANBANC;
            }
            if (filtro.name == 'CDEMPRESA'){
                filtro.value = transferencia.currentRow.CDEMPRESA;
            }
        });
        itens.reload();
        tabbed_itens.currentRow.DTTRANBANC = transferencia.currentRow.DTTRANBANC;
        tabbed_itens.currentRow.VRTRANBANC = transferencia.currentRow.VRTRANBANC;
        tabbed_itens.currentRow.DSHISTTBANC = transferencia.currentRow.DSHISTTBANC;
        deferred.resolve();
        return deferred.promise;
    };

    self.adicionarConta = function(itens){
        itens.newRow();
        //ScreenService.openSwipe(itens).then(function(){
            itens.currentRow.INSERT = true;
            itens.getAction('ADD').isVisible = false;
            itens.getAction('SAVE').isVisible = true;
            itens.getAction('SAVELIST').isVisible = false;
        //});
    };

    self.habilitaSaveList = function(){
        var itens = templateManager.container.getWidget('itensTransferencia');
        if (itens.getParent().currentRow.edit)
            itens.getAction('SAVELIST').isVisible = true;
    };

    self.concatenaCamposSelectMultiple = function(widget, fields, codigos){
        var field = null;
        for (i = 0; i < fields.length; i++) {
            field = widget.appliedFilter.getField(fields[i]);
            self.setValorConcatenado(widget, field, field.name, codigos[i], 'T'+field.name);
        }
    };

};

Configuration(function (ContextRegister){
    ContextRegister.register('Bco11100_transferenciaContaCorrente_Controller', Bco11100_transferenciaContaCorrente_Controller);
});